"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .activityitem import ActivityItem, ActivityItemTypedDict
    from .annotationaddedevent import (
        AnnotationAddedEvent,
        AnnotationAddedEventType,
        AnnotationAddedEventTypedDict,
    )
    from .applypatchservertool import (
        ApplyPatchServerTool,
        ApplyPatchServerToolType,
        ApplyPatchServerToolTypedDict,
    )
    from .badgatewayresponseerrordata import (
        BadGatewayResponseErrorData,
        BadGatewayResponseErrorDataTypedDict,
    )
    from .badrequestresponseerrordata import (
        BadRequestResponseErrorData,
        BadRequestResponseErrorDataTypedDict,
    )
    from .baseinputs_union import (
        BaseInputsContent1,
        BaseInputsContent1TypedDict,
        BaseInputsContent2,
        BaseInputsContent2TypedDict,
        BaseInputsContent3,
        BaseInputsContent3TypedDict,
        BaseInputsFunctionCall,
        BaseInputsFunctionCallOutput,
        BaseInputsFunctionCallOutputTypedDict,
        BaseInputsFunctionCallTypedDict,
        BaseInputsMessage1,
        BaseInputsMessage1TypedDict,
        BaseInputsMessage2,
        BaseInputsMessage2TypedDict,
        BaseInputsOutput1,
        BaseInputsOutput1TypedDict,
        BaseInputsOutput2,
        BaseInputsOutput2TypedDict,
        BaseInputsPhaseCommentary,
        BaseInputsPhaseFinalAnswer,
        BaseInputsPhaseUnion,
        BaseInputsPhaseUnionTypedDict,
        BaseInputsRoleAssistant,
        BaseInputsRoleDeveloper1,
        BaseInputsRoleDeveloper2,
        BaseInputsRoleSystem1,
        BaseInputsRoleSystem2,
        BaseInputsRoleUnion1,
        BaseInputsRoleUnion1TypedDict,
        BaseInputsRoleUnion2,
        BaseInputsRoleUnion2TypedDict,
        BaseInputsRoleUser1,
        BaseInputsRoleUser2,
        BaseInputsTypeFunctionCall,
        BaseInputsTypeFunctionCallOutput,
        BaseInputsTypeMessage1,
        BaseInputsTypeMessage2,
        BaseInputsUnion,
        BaseInputsUnion1,
        BaseInputsUnion1TypedDict,
        BaseInputsUnionTypedDict,
    )
    from .basereasoningconfig import BaseReasoningConfig, BaseReasoningConfigTypedDict
    from .chatassistantimages import (
        ChatAssistantImages,
        ChatAssistantImagesImageURL,
        ChatAssistantImagesImageURLTypedDict,
        ChatAssistantImagesTypedDict,
    )
    from .chatassistantmessage import (
        ChatAssistantMessage,
        ChatAssistantMessageContent,
        ChatAssistantMessageContentTypedDict,
        ChatAssistantMessageRole,
        ChatAssistantMessageTypedDict,
    )
    from .chataudiooutput import ChatAudioOutput, ChatAudioOutputTypedDict
    from .chatchoice import ChatChoice, ChatChoiceTypedDict
    from .chatcontentaudio import (
        ChatContentAudio,
        ChatContentAudioInputAudio,
        ChatContentAudioInputAudioTypedDict,
        ChatContentAudioType,
        ChatContentAudioTypedDict,
    )
    from .chatcontentcachecontrol import (
        ChatContentCacheControl,
        ChatContentCacheControlTTL,
        ChatContentCacheControlType,
        ChatContentCacheControlTypedDict,
    )
    from .chatcontentfile import (
        ChatContentFile,
        ChatContentFileType,
        ChatContentFileTypedDict,
        File,
        FileTypedDict,
    )
    from .chatcontentimage import (
        ChatContentImage,
        ChatContentImageDetail,
        ChatContentImageImageURL,
        ChatContentImageImageURLTypedDict,
        ChatContentImageType,
        ChatContentImageTypedDict,
    )
    from .chatcontentitems import (
        ChatContentItems,
        ChatContentItems1,
        ChatContentItems1TypedDict,
        ChatContentItemsTypedDict,
    )
    from .chatcontenttext import (
        ChatContentText,
        ChatContentTextType,
        ChatContentTextTypedDict,
    )
    from .chatcontentvideo import (
        ChatContentVideo,
        ChatContentVideoType,
        ChatContentVideoTypedDict,
    )
    from .chatcontentvideoinput import (
        ChatContentVideoInput,
        ChatContentVideoInputTypedDict,
    )
    from .chatdebugoptions import ChatDebugOptions, ChatDebugOptionsTypedDict
    from .chatdevelopermessage import (
        ChatDeveloperMessage,
        ChatDeveloperMessageContent,
        ChatDeveloperMessageContentTypedDict,
        ChatDeveloperMessageRole,
        ChatDeveloperMessageTypedDict,
    )
    from .chatfinishreasonenum import ChatFinishReasonEnum
    from .chatformatgrammarconfig import (
        ChatFormatGrammarConfig,
        ChatFormatGrammarConfigType,
        ChatFormatGrammarConfigTypedDict,
    )
    from .chatformatjsonschemaconfig import (
        ChatFormatJSONSchemaConfig,
        ChatFormatJSONSchemaConfigType,
        ChatFormatJSONSchemaConfigTypedDict,
    )
    from .chatformatpythonconfig import (
        ChatFormatPythonConfig,
        ChatFormatPythonConfigType,
        ChatFormatPythonConfigTypedDict,
    )
    from .chatformattextconfig import (
        ChatFormatTextConfig,
        ChatFormatTextConfigType,
        ChatFormatTextConfigTypedDict,
    )
    from .chatfunctiontool import (
        ChatFunctionTool,
        ChatFunctionToolFunction,
        ChatFunctionToolFunctionFunction,
        ChatFunctionToolFunctionFunctionTypedDict,
        ChatFunctionToolFunctionTypedDict,
        ChatFunctionToolType,
        ChatFunctionToolTypedDict,
    )
    from .chatjsonschemaconfig import (
        ChatJSONSchemaConfig,
        ChatJSONSchemaConfigTypedDict,
    )
    from .chatmessages import ChatMessages, ChatMessagesTypedDict
    from .chatnamedtoolchoice import (
        ChatNamedToolChoice,
        ChatNamedToolChoiceFunction,
        ChatNamedToolChoiceFunctionTypedDict,
        ChatNamedToolChoiceType,
        ChatNamedToolChoiceTypedDict,
    )
    from .chatreasoningsummaryverbosityenum import ChatReasoningSummaryVerbosityEnum
    from .chatrequest import (
        CacheControl,
        CacheControlTypedDict,
        ChatRequest,
        ChatRequestBy,
        ChatRequestIDAutoRouter,
        ChatRequestIDContextCompression,
        ChatRequestIDFileParser,
        ChatRequestIDModeration,
        ChatRequestIDResponseHealing,
        ChatRequestIDWeb,
        ChatRequestIgnore,
        ChatRequestIgnoreTypedDict,
        ChatRequestImageConfig,
        ChatRequestImageConfigTypedDict,
        ChatRequestMaxPrice,
        ChatRequestMaxPriceTypedDict,
        ChatRequestOnly,
        ChatRequestOnlyTypedDict,
        ChatRequestOrder,
        ChatRequestOrderTypedDict,
        ChatRequestPartition,
        ChatRequestPluginAutoRouter,
        ChatRequestPluginAutoRouterTypedDict,
        ChatRequestPluginContextCompression,
        ChatRequestPluginContextCompressionTypedDict,
        ChatRequestPluginFileParser,
        ChatRequestPluginFileParserTypedDict,
        ChatRequestPluginModeration,
        ChatRequestPluginModerationTypedDict,
        ChatRequestPluginResponseHealing,
        ChatRequestPluginResponseHealingTypedDict,
        ChatRequestPluginUnion,
        ChatRequestPluginUnionTypedDict,
        ChatRequestPluginWeb,
        ChatRequestPluginWebTypedDict,
        ChatRequestProvider,
        ChatRequestProviderSort,
        ChatRequestProviderSortConfig,
        ChatRequestProviderSortConfigEnum,
        ChatRequestProviderSortConfigTypedDict,
        ChatRequestProviderSortConfigUnion,
        ChatRequestProviderSortConfigUnionTypedDict,
        ChatRequestProviderTypedDict,
        ChatRequestServiceTier,
        ChatRequestSortEnum,
        ChatRequestSortUnion,
        ChatRequestSortUnionTypedDict,
        ChatRequestTTL,
        ChatRequestTrace,
        ChatRequestTraceTypedDict,
        ChatRequestType,
        ChatRequestTypedDict,
        Effort,
        Modality,
        Reasoning,
        ReasoningTypedDict,
        ResponseFormat,
        ResponseFormatTypedDict,
        Stop,
        StopTypedDict,
    )
    from .chatresult import ChatResult, ChatResultObject, ChatResultTypedDict
    from .chatstreamchoice import ChatStreamChoice, ChatStreamChoiceTypedDict
    from .chatstreamchunk import (
        ChatStreamChunk,
        ChatStreamChunkObject,
        ChatStreamChunkTypedDict,
        Error,
        ErrorTypedDict,
    )
    from .chatstreamdelta import (
        ChatStreamDelta,
        ChatStreamDeltaRole,
        ChatStreamDeltaTypedDict,
    )
    from .chatstreamoptions import ChatStreamOptions, ChatStreamOptionsTypedDict
    from .chatstreamtoolcall import (
        ChatStreamToolCall,
        ChatStreamToolCallFunction,
        ChatStreamToolCallFunctionTypedDict,
        ChatStreamToolCallType,
        ChatStreamToolCallTypedDict,
    )
    from .chatsystemmessage import (
        ChatSystemMessage,
        ChatSystemMessageContent,
        ChatSystemMessageContentTypedDict,
        ChatSystemMessageRole,
        ChatSystemMessageTypedDict,
    )
    from .chattokenlogprob import (
        ChatTokenLogprob,
        ChatTokenLogprobTopLogprob,
        ChatTokenLogprobTopLogprobTypedDict,
        ChatTokenLogprobTypedDict,
    )
    from .chattokenlogprobs import ChatTokenLogprobs, ChatTokenLogprobsTypedDict
    from .chattoolcall import (
        ChatToolCall,
        ChatToolCallFunction,
        ChatToolCallFunctionTypedDict,
        ChatToolCallType,
        ChatToolCallTypedDict,
    )
    from .chattoolchoice import (
        ChatToolChoice,
        ChatToolChoiceAuto,
        ChatToolChoiceNone,
        ChatToolChoiceRequired,
        ChatToolChoiceTypedDict,
    )
    from .chattoolmessage import (
        ChatToolMessage,
        ChatToolMessageContent,
        ChatToolMessageContentTypedDict,
        ChatToolMessageRole,
        ChatToolMessageTypedDict,
    )
    from .chatusage import (
        ChatUsage,
        ChatUsageTypedDict,
        CompletionTokensDetails,
        CompletionTokensDetailsTypedDict,
        PromptTokensDetails,
        PromptTokensDetailsTypedDict,
    )
    from .chatusermessage import (
        ChatUserMessage,
        ChatUserMessageContent,
        ChatUserMessageContentTypedDict,
        ChatUserMessageRole,
        ChatUserMessageTypedDict,
    )
    from .chatwebsearchservertool import (
        ChatWebSearchServerTool,
        ChatWebSearchServerToolEngine,
        ChatWebSearchServerToolParameters,
        ChatWebSearchServerToolParametersType,
        ChatWebSearchServerToolParametersTypedDict,
        ChatWebSearchServerToolSearchContextSize,
        ChatWebSearchServerToolTypeOpenrouterWebSearch,
        ChatWebSearchServerToolTypedDict,
        ChatWebSearchServerToolUserLocation,
        ChatWebSearchServerToolUserLocationTypedDict,
    )
    from .chatwebsearchshorthand import (
        ChatWebSearchShorthand,
        ChatWebSearchShorthandEngine,
        ChatWebSearchShorthandParameters,
        ChatWebSearchShorthandParametersEngine,
        ChatWebSearchShorthandParametersSearchContextSize,
        ChatWebSearchShorthandParametersType,
        ChatWebSearchShorthandParametersTypedDict,
        ChatWebSearchShorthandParametersUserLocation,
        ChatWebSearchShorthandParametersUserLocationTypedDict,
        ChatWebSearchShorthandSearchContextSize,
        ChatWebSearchShorthandType,
        ChatWebSearchShorthandTypeApproximate,
        ChatWebSearchShorthandTypedDict,
        ChatWebSearchShorthandUserLocation,
        ChatWebSearchShorthandUserLocationTypedDict,
    )
    from .codeinterpreterservertool import (
        CodeInterpreterServerTool,
        CodeInterpreterServerToolTypedDict,
        Container,
        ContainerAuto,
        ContainerAutoTypedDict,
        ContainerType,
        ContainerTypedDict,
        MemoryLimit,
        TypeCodeInterpreter,
    )
    from .codexlocalshelltool import (
        CodexLocalShellTool,
        CodexLocalShellToolType,
        CodexLocalShellToolTypedDict,
    )
    from .compoundfilter import (
        CompoundFilter,
        CompoundFilterType,
        CompoundFilterTypedDict,
    )
    from .computeruseservertool import (
        ComputerUseServerTool,
        ComputerUseServerToolType,
        ComputerUseServerToolTypedDict,
        Environment,
    )
    from .conflictresponseerrordata import (
        ConflictResponseErrorData,
        ConflictResponseErrorDataTypedDict,
    )
    from .contentpartaddedevent import (
        ContentPartAddedEvent,
        ContentPartAddedEventPart,
        ContentPartAddedEventPartTypedDict,
        ContentPartAddedEventType,
        ContentPartAddedEventTypedDict,
    )
    from .contentpartdoneevent import (
        ContentPartDoneEvent,
        ContentPartDoneEventPart,
        ContentPartDoneEventPartTypedDict,
        ContentPartDoneEventType,
        ContentPartDoneEventTypedDict,
    )
    from .contextcompressionengine import ContextCompressionEngine
    from .createchargerequest import (
        ChainID,
        CreateChargeRequest,
        CreateChargeRequestTypedDict,
    )
    from .customtool import (
        CustomTool,
        CustomToolTypedDict,
        Format,
        FormatGrammar,
        FormatGrammarTypedDict,
        FormatText,
        FormatTextTypedDict,
        FormatTypeGrammar,
        FormatTypeText,
        FormatTypedDict,
        Syntax,
        TypeCustom,
    )
    from .datacollection import DataCollection
    from .datetimeservertool import (
        DatetimeServerTool,
        DatetimeServerToolParameters,
        DatetimeServerToolParametersTypedDict,
        DatetimeServerToolType,
        DatetimeServerToolTypedDict,
    )
    from .defaultparameters import DefaultParameters, DefaultParametersTypedDict
    from .easyinputmessage import (
        EasyInputMessage,
        EasyInputMessageContentInputImage,
        EasyInputMessageContentInputImageTypedDict,
        EasyInputMessageContentType,
        EasyInputMessageContentUnion1,
        EasyInputMessageContentUnion1TypedDict,
        EasyInputMessageContentUnion2,
        EasyInputMessageContentUnion2TypedDict,
        EasyInputMessageDetail,
        EasyInputMessagePhaseCommentary,
        EasyInputMessagePhaseFinalAnswer,
        EasyInputMessagePhaseUnion,
        EasyInputMessagePhaseUnionTypedDict,
        EasyInputMessageRoleAssistant,
        EasyInputMessageRoleDeveloper,
        EasyInputMessageRoleSystem,
        EasyInputMessageRoleUnion,
        EasyInputMessageRoleUnionTypedDict,
        EasyInputMessageRoleUser,
        EasyInputMessageTypeMessage,
        EasyInputMessageTypedDict,
    )
    from .edgenetworktimeoutresponseerrordata import (
        EdgeNetworkTimeoutResponseErrorData,
        EdgeNetworkTimeoutResponseErrorDataTypedDict,
    )
    from .endpointstatus import EndpointStatus
    from .errorevent import ErrorEvent, ErrorEventType, ErrorEventTypedDict
    from .filecitation import FileCitation, FileCitationType, FileCitationTypedDict
    from .filepath import FilePath, FilePathType, FilePathTypedDict
    from .filesearchservertool import (
        FileSearchServerTool,
        FileSearchServerToolFilters,
        FileSearchServerToolFiltersTypedDict,
        FileSearchServerToolTypedDict,
        Filters,
        FiltersType,
        FiltersTypedDict,
        Ranker,
        RankingOptions,
        RankingOptionsTypedDict,
        TypeFileSearch,
        Value1,
        Value1TypedDict,
        Value2,
        Value2TypedDict,
    )
    from .forbiddenresponseerrordata import (
        ForbiddenResponseErrorData,
        ForbiddenResponseErrorDataTypedDict,
    )
    from .formatjsonobjectconfig import (
        FormatJSONObjectConfig,
        FormatJSONObjectConfigType,
        FormatJSONObjectConfigTypedDict,
    )
    from .formatjsonschemaconfig import (
        FormatJSONSchemaConfig,
        FormatJSONSchemaConfigType,
        FormatJSONSchemaConfigTypedDict,
    )
    from .formats import Formats, FormatsTypedDict
    from .formattextconfig import (
        FormatTextConfig,
        FormatTextConfigType,
        FormatTextConfigTypedDict,
    )
    from .functioncallargsdeltaevent import (
        FunctionCallArgsDeltaEvent,
        FunctionCallArgsDeltaEventType,
        FunctionCallArgsDeltaEventTypedDict,
    )
    from .functioncallargsdoneevent import (
        FunctionCallArgsDoneEvent,
        FunctionCallArgsDoneEventType,
        FunctionCallArgsDoneEventTypedDict,
    )
    from .functioncallitem import (
        FunctionCallItem,
        FunctionCallItemType,
        FunctionCallItemTypedDict,
    )
    from .functioncalloutputitem import (
        FunctionCallOutputItem,
        FunctionCallOutputItemDetail,
        FunctionCallOutputItemOutputUnion1,
        FunctionCallOutputItemOutputUnion1TypedDict,
        FunctionCallOutputItemOutputUnion2,
        FunctionCallOutputItemOutputUnion2TypedDict,
        FunctionCallOutputItemTypeFunctionCallOutput,
        FunctionCallOutputItemTypedDict,
        OutputInputImage,
        OutputInputImageTypedDict,
        OutputType,
    )
    from .imagegencallcompletedevent import (
        ImageGenCallCompletedEvent,
        ImageGenCallCompletedEventType,
        ImageGenCallCompletedEventTypedDict,
    )
    from .imagegencallgeneratingevent import (
        ImageGenCallGeneratingEvent,
        ImageGenCallGeneratingEventType,
        ImageGenCallGeneratingEventTypedDict,
    )
    from .imagegencallinprogressevent import (
        ImageGenCallInProgressEvent,
        ImageGenCallInProgressEventType,
        ImageGenCallInProgressEventTypedDict,
    )
    from .imagegencallpartialimageevent import (
        ImageGenCallPartialImageEvent,
        ImageGenCallPartialImageEventType,
        ImageGenCallPartialImageEventTypedDict,
    )
    from .imagegenerationservertool import (
        Background,
        ImageGenerationServerTool,
        ImageGenerationServerToolType,
        ImageGenerationServerToolTypedDict,
        InputFidelity,
        InputImageMask,
        InputImageMaskTypedDict,
        ModelEnum,
        Moderation,
        OutputFormat,
        Quality,
        Size,
    )
    from .imagegenerationstatus import ImageGenerationStatus
    from .incompletedetails import IncompleteDetails, IncompleteDetailsTypedDict, Reason
    from .inputaudio import (
        InputAudio,
        InputAudioFormat,
        InputAudioInputAudio,
        InputAudioInputAudioTypedDict,
        InputAudioType,
        InputAudioTypedDict,
    )
    from .inputfile import InputFile, InputFileType, InputFileTypedDict
    from .inputimage import (
        InputImage,
        InputImageDetail,
        InputImageType,
        InputImageTypedDict,
    )
    from .inputmessageitem import (
        InputMessageItem,
        InputMessageItemContentInputImage,
        InputMessageItemContentInputImageTypedDict,
        InputMessageItemContentType,
        InputMessageItemContentUnion,
        InputMessageItemContentUnionTypedDict,
        InputMessageItemDetail,
        InputMessageItemRoleDeveloper,
        InputMessageItemRoleSystem,
        InputMessageItemRoleUnion,
        InputMessageItemRoleUnionTypedDict,
        InputMessageItemRoleUser,
        InputMessageItemTypeMessage,
        InputMessageItemTypedDict,
    )
    from .inputmodality import InputModality
    from .inputs_union import (
        InputsContent1,
        InputsContent1TypedDict,
        InputsContent2,
        InputsContent2TypedDict,
        InputsFormat,
        InputsMessage,
        InputsMessageTypedDict,
        InputsPhaseCommentary,
        InputsPhaseFinalAnswer,
        InputsPhaseUnion,
        InputsPhaseUnionTypedDict,
        InputsReasoning,
        InputsReasoningTypedDict,
        InputsRole,
        InputsStatusCompleted1,
        InputsStatusCompleted2,
        InputsStatusInProgress1,
        InputsStatusInProgress2,
        InputsStatusIncomplete1,
        InputsStatusIncomplete2,
        InputsStatusUnion1,
        InputsStatusUnion1TypedDict,
        InputsStatusUnion2,
        InputsStatusUnion2TypedDict,
        InputsTypeMessage,
        InputsTypeReasoning,
        InputsUnion,
        InputsUnion1,
        InputsUnion1TypedDict,
        InputsUnionTypedDict,
    )
    from .inputtext import InputText, InputTextType, InputTextTypedDict
    from .inputvideo import InputVideo, InputVideoType, InputVideoTypedDict
    from .instructtype import InstructType
    from .internalserverresponseerrordata import (
        InternalServerResponseErrorData,
        InternalServerResponseErrorDataTypedDict,
    )
    from .legacy_chatcontentvideo import (
        LegacyChatContentVideo,
        LegacyChatContentVideoType,
        LegacyChatContentVideoTypedDict,
    )
    from .legacy_websearchservertool import (
        LegacyWebSearchServerTool,
        LegacyWebSearchServerToolEngine,
        LegacyWebSearchServerToolFilters,
        LegacyWebSearchServerToolFiltersTypedDict,
        LegacyWebSearchServerToolType,
        LegacyWebSearchServerToolTypedDict,
    )
    from .listendpointsresponse import (
        Architecture,
        ArchitectureTypedDict,
        ListEndpointsResponse,
        ListEndpointsResponseTypedDict,
        Tokenizer,
    )
    from .mcpservertool import (
        AllowedTools,
        AllowedToolsTypedDict,
        Always,
        AlwaysTypedDict,
        ConnectorID,
        McpServerTool,
        McpServerToolType,
        McpServerToolTypedDict,
        Never,
        NeverTypedDict,
        RequireApproval,
        RequireApprovalAlways,
        RequireApprovalNever,
        RequireApprovalTypedDict,
    )
    from .model import Model, ModelTypedDict
    from .modelarchitecture import (
        ModelArchitecture,
        ModelArchitectureInstructType,
        ModelArchitectureTypedDict,
    )
    from .modelgroup import ModelGroup
    from .modelscountresponse import (
        Data,
        DataTypedDict,
        ModelsCountResponse,
        ModelsCountResponseTypedDict,
    )
    from .modelslistresponse import ModelsListResponse, ModelsListResponseTypedDict
    from .notfoundresponseerrordata import (
        NotFoundResponseErrorData,
        NotFoundResponseErrorDataTypedDict,
    )
    from .openairesponsesannotation import (
        OpenAIResponsesAnnotation,
        OpenAIResponsesAnnotationTypedDict,
    )
    from .openairesponsesrefusalcontent import (
        OpenAIResponsesRefusalContent,
        OpenAIResponsesRefusalContentType,
        OpenAIResponsesRefusalContentTypedDict,
    )
    from .openairesponsesresponsestatus import OpenAIResponsesResponseStatus
    from .openairesponsestoolchoice_union import (
        OpenAIResponsesToolChoice,
        OpenAIResponsesToolChoiceAuto,
        OpenAIResponsesToolChoiceFunction,
        OpenAIResponsesToolChoiceFunctionTypedDict,
        OpenAIResponsesToolChoiceNone,
        OpenAIResponsesToolChoiceRequired,
        OpenAIResponsesToolChoiceTypeFunction,
        OpenAIResponsesToolChoiceTypeWebSearchPreview,
        OpenAIResponsesToolChoiceTypeWebSearchPreview20250311,
        OpenAIResponsesToolChoiceTypedDict,
        OpenAIResponsesToolChoiceUnion,
        OpenAIResponsesToolChoiceUnionTypedDict,
        Type,
        TypeTypedDict,
    )
    from .openairesponsestruncation import OpenAIResponsesTruncation
    from .openresponsesresult import (
        OpenResponsesResult,
        OpenResponsesResultObject,
        OpenResponsesResultToolFunction,
        OpenResponsesResultToolFunctionTypedDict,
        OpenResponsesResultToolUnion,
        OpenResponsesResultToolUnionTypedDict,
        OpenResponsesResultType,
        OpenResponsesResultTypedDict,
    )
    from .outputdatetimeitem import (
        OutputDatetimeItem,
        OutputDatetimeItemStatus,
        OutputDatetimeItemType,
        OutputDatetimeItemTypedDict,
    )
    from .outputfilesearchcallitem import (
        OutputFileSearchCallItem,
        OutputFileSearchCallItemType,
        OutputFileSearchCallItemTypedDict,
    )
    from .outputfunctioncallitem import (
        OutputFunctionCallItem,
        OutputFunctionCallItemStatusCompleted,
        OutputFunctionCallItemStatusInProgress,
        OutputFunctionCallItemStatusIncomplete,
        OutputFunctionCallItemStatusUnion,
        OutputFunctionCallItemStatusUnionTypedDict,
        OutputFunctionCallItemType,
        OutputFunctionCallItemTypedDict,
    )
    from .outputimagegenerationcallitem import (
        OutputImageGenerationCallItem,
        OutputImageGenerationCallItemType,
        OutputImageGenerationCallItemTypedDict,
    )
    from .outputitemimagegenerationcall import (
        OutputItemImageGenerationCall,
        OutputItemImageGenerationCallType,
        OutputItemImageGenerationCallTypedDict,
    )
    from .outputitems import OutputItems, OutputItemsTypedDict
    from .outputmessage import (
        OutputMessage,
        OutputMessageContent,
        OutputMessageContentTypedDict,
        OutputMessagePhaseCommentary,
        OutputMessagePhaseFinalAnswer,
        OutputMessagePhaseUnion,
        OutputMessagePhaseUnionTypedDict,
        OutputMessageRole,
        OutputMessageStatusCompleted,
        OutputMessageStatusInProgress,
        OutputMessageStatusIncomplete,
        OutputMessageStatusUnion,
        OutputMessageStatusUnionTypedDict,
        OutputMessageType,
        OutputMessageTypedDict,
    )
    from .outputmessageitem import (
        OutputMessageItem,
        OutputMessageItemContent,
        OutputMessageItemContentTypedDict,
        OutputMessageItemPhaseCommentary,
        OutputMessageItemPhaseFinalAnswer,
        OutputMessageItemPhaseUnion,
        OutputMessageItemPhaseUnionTypedDict,
        OutputMessageItemRole,
        OutputMessageItemStatusCompleted,
        OutputMessageItemStatusInProgress,
        OutputMessageItemStatusIncomplete,
        OutputMessageItemStatusUnion,
        OutputMessageItemStatusUnionTypedDict,
        OutputMessageItemType,
        OutputMessageItemTypedDict,
    )
    from .outputmodality import OutputModality
    from .outputmodalityenum import OutputModalityEnum
    from .outputreasoningitem import (
        OutputReasoningItem,
        OutputReasoningItemFormat,
        OutputReasoningItemStatusCompleted,
        OutputReasoningItemStatusInProgress,
        OutputReasoningItemStatusIncomplete,
        OutputReasoningItemStatusUnion,
        OutputReasoningItemStatusUnionTypedDict,
        OutputReasoningItemType,
        OutputReasoningItemTypedDict,
    )
    from .outputservertoolitem import (
        OutputServerToolItem,
        OutputServerToolItemStatus,
        OutputServerToolItemTypedDict,
    )
    from .outputwebsearchcallitem import (
        Action,
        ActionFindInPage,
        ActionFindInPageTypedDict,
        ActionOpenPage,
        ActionOpenPageTypedDict,
        ActionSearch,
        ActionSearchTypedDict,
        ActionTypedDict,
        OutputWebSearchCallItem,
        OutputWebSearchCallItemTypedDict,
        Source,
        SourceTypedDict,
        TypeFindInPage,
        TypeOpenPage,
        TypeSearch,
        TypeURL,
        TypeWebSearchCall,
    )
    from .parameter import Parameter
    from .payloadtoolargeresponseerrordata import (
        PayloadTooLargeResponseErrorData,
        PayloadTooLargeResponseErrorDataTypedDict,
    )
    from .paymentrequiredresponseerrordata import (
        PaymentRequiredResponseErrorData,
        PaymentRequiredResponseErrorDataTypedDict,
    )
    from .pdfparserengine import (
        PDFParserEngine,
        PDFParserEngineEnum,
        PDFParserEnginePDFText,
        PDFParserEngineTypedDict,
    )
    from .pdfparseroptions import PDFParserOptions, PDFParserOptionsTypedDict
    from .percentilelatencycutoffs import (
        PercentileLatencyCutoffs,
        PercentileLatencyCutoffsTypedDict,
    )
    from .percentilestats import PercentileStats, PercentileStatsTypedDict
    from .percentilethroughputcutoffs import (
        PercentileThroughputCutoffs,
        PercentileThroughputCutoffsTypedDict,
    )
    from .perrequestlimits import PerRequestLimits, PerRequestLimitsTypedDict
    from .preferredmaxlatency import PreferredMaxLatency, PreferredMaxLatencyTypedDict
    from .preferredminthroughput import (
        PreferredMinThroughput,
        PreferredMinThroughputTypedDict,
    )
    from .preview_20250311_websearchservertool import (
        Preview20250311WebSearchServerTool,
        Preview20250311WebSearchServerToolEngine,
        Preview20250311WebSearchServerToolFilters,
        Preview20250311WebSearchServerToolFiltersTypedDict,
        Preview20250311WebSearchServerToolType,
        Preview20250311WebSearchServerToolTypedDict,
    )
    from .preview_websearchservertool import (
        PreviewWebSearchServerTool,
        PreviewWebSearchServerToolEngine,
        PreviewWebSearchServerToolFilters,
        PreviewWebSearchServerToolFiltersTypedDict,
        PreviewWebSearchServerToolType,
        PreviewWebSearchServerToolTypedDict,
    )
    from .preview_websearchuserlocation import (
        PreviewWebSearchUserLocation,
        PreviewWebSearchUserLocationType,
        PreviewWebSearchUserLocationTypedDict,
    )
    from .providername import ProviderName
    from .provideroverloadedresponseerrordata import (
        ProviderOverloadedResponseErrorData,
        ProviderOverloadedResponseErrorDataTypedDict,
    )
    from .providerpreferences import (
        ProviderPreferences,
        ProviderPreferencesBy,
        ProviderPreferencesIgnore,
        ProviderPreferencesIgnoreTypedDict,
        ProviderPreferencesMaxPrice,
        ProviderPreferencesMaxPriceTypedDict,
        ProviderPreferencesOnly,
        ProviderPreferencesOnlyTypedDict,
        ProviderPreferencesOrder,
        ProviderPreferencesOrderTypedDict,
        ProviderPreferencesPartition,
        ProviderPreferencesProviderSort,
        ProviderPreferencesProviderSortConfig,
        ProviderPreferencesProviderSortConfigEnum,
        ProviderPreferencesProviderSortConfigTypedDict,
        ProviderPreferencesProviderSortConfigUnion,
        ProviderPreferencesProviderSortConfigUnionTypedDict,
        ProviderPreferencesSortEnum,
        ProviderPreferencesSortUnion,
        ProviderPreferencesSortUnionTypedDict,
        ProviderPreferencesTypedDict,
    )
    from .providersort import ProviderSort
    from .providersortconfig import (
        By,
        Partition,
        ProviderSortConfig,
        ProviderSortConfigTypedDict,
    )
    from .publicendpoint import (
        Pricing,
        PricingTypedDict,
        PublicEndpoint,
        PublicEndpointQuantization,
        PublicEndpointTypedDict,
    )
    from .publicpricing import PublicPricing, PublicPricingTypedDict
    from .quantization import Quantization
    from .reasoningconfig import ReasoningConfig, ReasoningConfigTypedDict
    from .reasoningdeltaevent import (
        ReasoningDeltaEvent,
        ReasoningDeltaEventType,
        ReasoningDeltaEventTypedDict,
    )
    from .reasoningdetailencrypted import (
        ReasoningDetailEncrypted,
        ReasoningDetailEncryptedFormat,
        ReasoningDetailEncryptedType,
        ReasoningDetailEncryptedTypedDict,
    )
    from .reasoningdetailsummary import (
        ReasoningDetailSummary,
        ReasoningDetailSummaryFormat,
        ReasoningDetailSummaryType,
        ReasoningDetailSummaryTypedDict,
    )
    from .reasoningdetailtext import (
        ReasoningDetailText,
        ReasoningDetailTextFormat,
        ReasoningDetailTextType,
        ReasoningDetailTextTypedDict,
    )
    from .reasoningdetailunion import (
        ReasoningDetailUnion,
        ReasoningDetailUnionTypedDict,
    )
    from .reasoningdoneevent import (
        ReasoningDoneEvent,
        ReasoningDoneEventType,
        ReasoningDoneEventTypedDict,
    )
    from .reasoningeffortenum import ReasoningEffortEnum
    from .reasoningitem import (
        ReasoningItem,
        ReasoningItemFormat,
        ReasoningItemStatusCompleted,
        ReasoningItemStatusInProgress,
        ReasoningItemStatusIncomplete,
        ReasoningItemStatusUnion,
        ReasoningItemStatusUnionTypedDict,
        ReasoningItemType,
        ReasoningItemTypedDict,
    )
    from .reasoningsummarypartaddedevent import (
        ReasoningSummaryPartAddedEvent,
        ReasoningSummaryPartAddedEventType,
        ReasoningSummaryPartAddedEventTypedDict,
    )
    from .reasoningsummarypartdoneevent import (
        ReasoningSummaryPartDoneEvent,
        ReasoningSummaryPartDoneEventType,
        ReasoningSummaryPartDoneEventTypedDict,
    )
    from .reasoningsummarytext import (
        ReasoningSummaryText,
        ReasoningSummaryTextType,
        ReasoningSummaryTextTypedDict,
    )
    from .reasoningsummarytextdeltaevent import (
        ReasoningSummaryTextDeltaEvent,
        ReasoningSummaryTextDeltaEventType,
        ReasoningSummaryTextDeltaEventTypedDict,
    )
    from .reasoningsummarytextdoneevent import (
        ReasoningSummaryTextDoneEvent,
        ReasoningSummaryTextDoneEventType,
        ReasoningSummaryTextDoneEventTypedDict,
    )
    from .reasoningsummaryverbosityenum import ReasoningSummaryVerbosityEnum
    from .reasoningtextcontent import (
        ReasoningTextContent,
        ReasoningTextContentType,
        ReasoningTextContentTypedDict,
    )
    from .refusaldeltaevent import (
        RefusalDeltaEvent,
        RefusalDeltaEventType,
        RefusalDeltaEventTypedDict,
    )
    from .refusaldoneevent import (
        RefusalDoneEvent,
        RefusalDoneEventType,
        RefusalDoneEventTypedDict,
    )
    from .requesttimeoutresponseerrordata import (
        RequestTimeoutResponseErrorData,
        RequestTimeoutResponseErrorDataTypedDict,
    )
    from .responseincludesenum import ResponseIncludesEnum
    from .responseoutputtext import (
        ResponseOutputText,
        ResponseOutputTextLogprob,
        ResponseOutputTextLogprobTypedDict,
        ResponseOutputTextTopLogprob,
        ResponseOutputTextTopLogprobTypedDict,
        ResponseOutputTextType,
        ResponseOutputTextTypedDict,
    )
    from .responseserrorfield import (
        Code,
        ResponsesErrorField,
        ResponsesErrorFieldTypedDict,
    )
    from .responsesrequest import (
        ResponsesRequest,
        ResponsesRequestIDAutoRouter,
        ResponsesRequestIDContextCompression,
        ResponsesRequestIDFileParser,
        ResponsesRequestIDModeration,
        ResponsesRequestIDResponseHealing,
        ResponsesRequestIDWeb,
        ResponsesRequestIgnore,
        ResponsesRequestIgnoreTypedDict,
        ResponsesRequestImageConfig,
        ResponsesRequestImageConfigTypedDict,
        ResponsesRequestMaxPrice,
        ResponsesRequestMaxPriceTypedDict,
        ResponsesRequestOnly,
        ResponsesRequestOnlyTypedDict,
        ResponsesRequestOrder,
        ResponsesRequestOrderTypedDict,
        ResponsesRequestPluginAutoRouter,
        ResponsesRequestPluginAutoRouterTypedDict,
        ResponsesRequestPluginContextCompression,
        ResponsesRequestPluginContextCompressionTypedDict,
        ResponsesRequestPluginFileParser,
        ResponsesRequestPluginFileParserTypedDict,
        ResponsesRequestPluginModeration,
        ResponsesRequestPluginModerationTypedDict,
        ResponsesRequestPluginResponseHealing,
        ResponsesRequestPluginResponseHealingTypedDict,
        ResponsesRequestPluginUnion,
        ResponsesRequestPluginUnionTypedDict,
        ResponsesRequestPluginWeb,
        ResponsesRequestPluginWebTypedDict,
        ResponsesRequestProvider,
        ResponsesRequestProviderTypedDict,
        ResponsesRequestServiceTier,
        ResponsesRequestSort,
        ResponsesRequestSortTypedDict,
        ResponsesRequestToolFunction,
        ResponsesRequestToolFunctionTypedDict,
        ResponsesRequestToolUnion,
        ResponsesRequestToolUnionTypedDict,
        ResponsesRequestTrace,
        ResponsesRequestTraceTypedDict,
        ResponsesRequestType,
        ResponsesRequestTypedDict,
    )
    from .searchcontextsizeenum import SearchContextSizeEnum
    from .security import Security, SecurityTypedDict
    from .serviceunavailableresponseerrordata import (
        ServiceUnavailableResponseErrorData,
        ServiceUnavailableResponseErrorDataTypedDict,
    )
    from .shellservertool import (
        ShellServerTool,
        ShellServerToolType,
        ShellServerToolTypedDict,
    )
    from .storedprompttemplate import (
        StoredPromptTemplate,
        StoredPromptTemplateTypedDict,
        Variables,
        VariablesTypedDict,
    )
    from .streamevents import (
        StreamEvents,
        StreamEventsResponseCompleted,
        StreamEventsResponseCompletedTypedDict,
        StreamEventsResponseCreated,
        StreamEventsResponseCreatedTypedDict,
        StreamEventsResponseFailed,
        StreamEventsResponseFailedTypedDict,
        StreamEventsResponseInProgress,
        StreamEventsResponseInProgressTypedDict,
        StreamEventsResponseIncomplete,
        StreamEventsResponseIncompleteTypedDict,
        StreamEventsResponseOutputItemAdded,
        StreamEventsResponseOutputItemAddedTypedDict,
        StreamEventsResponseOutputItemDone,
        StreamEventsResponseOutputItemDoneTypedDict,
        StreamEventsTypedDict,
        TypeResponseCompleted,
        TypeResponseCreated,
        TypeResponseFailed,
        TypeResponseInProgress,
        TypeResponseIncomplete,
        TypeResponseOutputItemAdded,
        TypeResponseOutputItemDone,
    )
    from .textconfig import TextConfig, TextConfigTypedDict, TextConfigVerbosity
    from .textdeltaevent import (
        TextDeltaEvent,
        TextDeltaEventLogprob,
        TextDeltaEventLogprobTypedDict,
        TextDeltaEventTopLogprob,
        TextDeltaEventTopLogprobTypedDict,
        TextDeltaEventType,
        TextDeltaEventTypedDict,
    )
    from .textdoneevent import (
        TextDoneEvent,
        TextDoneEventLogprob,
        TextDoneEventLogprobTypedDict,
        TextDoneEventTopLogprob,
        TextDoneEventTopLogprobTypedDict,
        TextDoneEventType,
        TextDoneEventTypedDict,
    )
    from .textextendedconfig import (
        TextExtendedConfig,
        TextExtendedConfigTypedDict,
        TextExtendedConfigVerbosity,
    )
    from .toolcallstatusenum import ToolCallStatusEnum
    from .toomanyrequestsresponseerrordata import (
        TooManyRequestsResponseErrorData,
        TooManyRequestsResponseErrorDataTypedDict,
    )
    from .topproviderinfo import TopProviderInfo, TopProviderInfoTypedDict
    from .truncationenum import TruncationEnum
    from .unauthorizedresponseerrordata import (
        UnauthorizedResponseErrorData,
        UnauthorizedResponseErrorDataTypedDict,
    )
    from .unprocessableentityresponseerrordata import (
        UnprocessableEntityResponseErrorData,
        UnprocessableEntityResponseErrorDataTypedDict,
    )
    from .urlcitation import URLCitation, URLCitationType, URLCitationTypedDict
    from .usage import (
        CostDetails,
        CostDetailsTypedDict,
        InputTokensDetails,
        InputTokensDetailsTypedDict,
        OutputTokensDetails,
        OutputTokensDetailsTypedDict,
        Usage,
        UsageTypedDict,
    )
    from .websearchcallcompletedevent import (
        WebSearchCallCompletedEvent,
        WebSearchCallCompletedEventType,
        WebSearchCallCompletedEventTypedDict,
    )
    from .websearchcallinprogressevent import (
        WebSearchCallInProgressEvent,
        WebSearchCallInProgressEventType,
        WebSearchCallInProgressEventTypedDict,
    )
    from .websearchcallsearchingevent import (
        WebSearchCallSearchingEvent,
        WebSearchCallSearchingEventType,
        WebSearchCallSearchingEventTypedDict,
    )
    from .websearchengine import WebSearchEngine
    from .websearchservertool import (
        WebSearchServerTool,
        WebSearchServerToolEngine,
        WebSearchServerToolFilters,
        WebSearchServerToolFiltersTypedDict,
        WebSearchServerToolType,
        WebSearchServerToolTypedDict,
    )
    from .websearchservertool_openrouter import (
        WebSearchServerToolOpenRouter,
        WebSearchServerToolOpenRouterParameters,
        WebSearchServerToolOpenRouterParametersTypedDict,
        WebSearchServerToolOpenRouterType,
        WebSearchServerToolOpenRouterTypedDict,
    )
    from .websearchstatus import WebSearchStatus
    from .websearchuserlocation import (
        WebSearchUserLocation,
        WebSearchUserLocationType,
        WebSearchUserLocationTypedDict,
    )

__all__ = [
    "Action",
    "ActionFindInPage",
    "ActionFindInPageTypedDict",
    "ActionOpenPage",
    "ActionOpenPageTypedDict",
    "ActionSearch",
    "ActionSearchTypedDict",
    "ActionTypedDict",
    "ActivityItem",
    "ActivityItemTypedDict",
    "AllowedTools",
    "AllowedToolsTypedDict",
    "Always",
    "AlwaysTypedDict",
    "AnnotationAddedEvent",
    "AnnotationAddedEventType",
    "AnnotationAddedEventTypedDict",
    "ApplyPatchServerTool",
    "ApplyPatchServerToolType",
    "ApplyPatchServerToolTypedDict",
    "Architecture",
    "ArchitectureTypedDict",
    "Background",
    "BadGatewayResponseErrorData",
    "BadGatewayResponseErrorDataTypedDict",
    "BadRequestResponseErrorData",
    "BadRequestResponseErrorDataTypedDict",
    "BaseInputsContent1",
    "BaseInputsContent1TypedDict",
    "BaseInputsContent2",
    "BaseInputsContent2TypedDict",
    "BaseInputsContent3",
    "BaseInputsContent3TypedDict",
    "BaseInputsFunctionCall",
    "BaseInputsFunctionCallOutput",
    "BaseInputsFunctionCallOutputTypedDict",
    "BaseInputsFunctionCallTypedDict",
    "BaseInputsMessage1",
    "BaseInputsMessage1TypedDict",
    "BaseInputsMessage2",
    "BaseInputsMessage2TypedDict",
    "BaseInputsOutput1",
    "BaseInputsOutput1TypedDict",
    "BaseInputsOutput2",
    "BaseInputsOutput2TypedDict",
    "BaseInputsPhaseCommentary",
    "BaseInputsPhaseFinalAnswer",
    "BaseInputsPhaseUnion",
    "BaseInputsPhaseUnionTypedDict",
    "BaseInputsRoleAssistant",
    "BaseInputsRoleDeveloper1",
    "BaseInputsRoleDeveloper2",
    "BaseInputsRoleSystem1",
    "BaseInputsRoleSystem2",
    "BaseInputsRoleUnion1",
    "BaseInputsRoleUnion1TypedDict",
    "BaseInputsRoleUnion2",
    "BaseInputsRoleUnion2TypedDict",
    "BaseInputsRoleUser1",
    "BaseInputsRoleUser2",
    "BaseInputsTypeFunctionCall",
    "BaseInputsTypeFunctionCallOutput",
    "BaseInputsTypeMessage1",
    "BaseInputsTypeMessage2",
    "BaseInputsUnion",
    "BaseInputsUnion1",
    "BaseInputsUnion1TypedDict",
    "BaseInputsUnionTypedDict",
    "BaseReasoningConfig",
    "BaseReasoningConfigTypedDict",
    "By",
    "CacheControl",
    "CacheControlTypedDict",
    "ChainID",
    "ChatAssistantImages",
    "ChatAssistantImagesImageURL",
    "ChatAssistantImagesImageURLTypedDict",
    "ChatAssistantImagesTypedDict",
    "ChatAssistantMessage",
    "ChatAssistantMessageContent",
    "ChatAssistantMessageContentTypedDict",
    "ChatAssistantMessageRole",
    "ChatAssistantMessageTypedDict",
    "ChatAudioOutput",
    "ChatAudioOutputTypedDict",
    "ChatChoice",
    "ChatChoiceTypedDict",
    "ChatContentAudio",
    "ChatContentAudioInputAudio",
    "ChatContentAudioInputAudioTypedDict",
    "ChatContentAudioType",
    "ChatContentAudioTypedDict",
    "ChatContentCacheControl",
    "ChatContentCacheControlTTL",
    "ChatContentCacheControlType",
    "ChatContentCacheControlTypedDict",
    "ChatContentFile",
    "ChatContentFileType",
    "ChatContentFileTypedDict",
    "ChatContentImage",
    "ChatContentImageDetail",
    "ChatContentImageImageURL",
    "ChatContentImageImageURLTypedDict",
    "ChatContentImageType",
    "ChatContentImageTypedDict",
    "ChatContentItems",
    "ChatContentItems1",
    "ChatContentItems1TypedDict",
    "ChatContentItemsTypedDict",
    "ChatContentText",
    "ChatContentTextType",
    "ChatContentTextTypedDict",
    "ChatContentVideo",
    "ChatContentVideoInput",
    "ChatContentVideoInputTypedDict",
    "ChatContentVideoType",
    "ChatContentVideoTypedDict",
    "ChatDebugOptions",
    "ChatDebugOptionsTypedDict",
    "ChatDeveloperMessage",
    "ChatDeveloperMessageContent",
    "ChatDeveloperMessageContentTypedDict",
    "ChatDeveloperMessageRole",
    "ChatDeveloperMessageTypedDict",
    "ChatFinishReasonEnum",
    "ChatFormatGrammarConfig",
    "ChatFormatGrammarConfigType",
    "ChatFormatGrammarConfigTypedDict",
    "ChatFormatJSONSchemaConfig",
    "ChatFormatJSONSchemaConfigType",
    "ChatFormatJSONSchemaConfigTypedDict",
    "ChatFormatPythonConfig",
    "ChatFormatPythonConfigType",
    "ChatFormatPythonConfigTypedDict",
    "ChatFormatTextConfig",
    "ChatFormatTextConfigType",
    "ChatFormatTextConfigTypedDict",
    "ChatFunctionTool",
    "ChatFunctionToolFunction",
    "ChatFunctionToolFunctionFunction",
    "ChatFunctionToolFunctionFunctionTypedDict",
    "ChatFunctionToolFunctionTypedDict",
    "ChatFunctionToolType",
    "ChatFunctionToolTypedDict",
    "ChatJSONSchemaConfig",
    "ChatJSONSchemaConfigTypedDict",
    "ChatMessages",
    "ChatMessagesTypedDict",
    "ChatNamedToolChoice",
    "ChatNamedToolChoiceFunction",
    "ChatNamedToolChoiceFunctionTypedDict",
    "ChatNamedToolChoiceType",
    "ChatNamedToolChoiceTypedDict",
    "ChatReasoningSummaryVerbosityEnum",
    "ChatRequest",
    "ChatRequestBy",
    "ChatRequestIDAutoRouter",
    "ChatRequestIDContextCompression",
    "ChatRequestIDFileParser",
    "ChatRequestIDModeration",
    "ChatRequestIDResponseHealing",
    "ChatRequestIDWeb",
    "ChatRequestIgnore",
    "ChatRequestIgnoreTypedDict",
    "ChatRequestImageConfig",
    "ChatRequestImageConfigTypedDict",
    "ChatRequestMaxPrice",
    "ChatRequestMaxPriceTypedDict",
    "ChatRequestOnly",
    "ChatRequestOnlyTypedDict",
    "ChatRequestOrder",
    "ChatRequestOrderTypedDict",
    "ChatRequestPartition",
    "ChatRequestPluginAutoRouter",
    "ChatRequestPluginAutoRouterTypedDict",
    "ChatRequestPluginContextCompression",
    "ChatRequestPluginContextCompressionTypedDict",
    "ChatRequestPluginFileParser",
    "ChatRequestPluginFileParserTypedDict",
    "ChatRequestPluginModeration",
    "ChatRequestPluginModerationTypedDict",
    "ChatRequestPluginResponseHealing",
    "ChatRequestPluginResponseHealingTypedDict",
    "ChatRequestPluginUnion",
    "ChatRequestPluginUnionTypedDict",
    "ChatRequestPluginWeb",
    "ChatRequestPluginWebTypedDict",
    "ChatRequestProvider",
    "ChatRequestProviderSort",
    "ChatRequestProviderSortConfig",
    "ChatRequestProviderSortConfigEnum",
    "ChatRequestProviderSortConfigTypedDict",
    "ChatRequestProviderSortConfigUnion",
    "ChatRequestProviderSortConfigUnionTypedDict",
    "ChatRequestProviderTypedDict",
    "ChatRequestServiceTier",
    "ChatRequestSortEnum",
    "ChatRequestSortUnion",
    "ChatRequestSortUnionTypedDict",
    "ChatRequestTTL",
    "ChatRequestTrace",
    "ChatRequestTraceTypedDict",
    "ChatRequestType",
    "ChatRequestTypedDict",
    "ChatResult",
    "ChatResultObject",
    "ChatResultTypedDict",
    "ChatStreamChoice",
    "ChatStreamChoiceTypedDict",
    "ChatStreamChunk",
    "ChatStreamChunkObject",
    "ChatStreamChunkTypedDict",
    "ChatStreamDelta",
    "ChatStreamDeltaRole",
    "ChatStreamDeltaTypedDict",
    "ChatStreamOptions",
    "ChatStreamOptionsTypedDict",
    "ChatStreamToolCall",
    "ChatStreamToolCallFunction",
    "ChatStreamToolCallFunctionTypedDict",
    "ChatStreamToolCallType",
    "ChatStreamToolCallTypedDict",
    "ChatSystemMessage",
    "ChatSystemMessageContent",
    "ChatSystemMessageContentTypedDict",
    "ChatSystemMessageRole",
    "ChatSystemMessageTypedDict",
    "ChatTokenLogprob",
    "ChatTokenLogprobTopLogprob",
    "ChatTokenLogprobTopLogprobTypedDict",
    "ChatTokenLogprobTypedDict",
    "ChatTokenLogprobs",
    "ChatTokenLogprobsTypedDict",
    "ChatToolCall",
    "ChatToolCallFunction",
    "ChatToolCallFunctionTypedDict",
    "ChatToolCallType",
    "ChatToolCallTypedDict",
    "ChatToolChoice",
    "ChatToolChoiceAuto",
    "ChatToolChoiceNone",
    "ChatToolChoiceRequired",
    "ChatToolChoiceTypedDict",
    "ChatToolMessage",
    "ChatToolMessageContent",
    "ChatToolMessageContentTypedDict",
    "ChatToolMessageRole",
    "ChatToolMessageTypedDict",
    "ChatUsage",
    "ChatUsageTypedDict",
    "ChatUserMessage",
    "ChatUserMessageContent",
    "ChatUserMessageContentTypedDict",
    "ChatUserMessageRole",
    "ChatUserMessageTypedDict",
    "ChatWebSearchServerTool",
    "ChatWebSearchServerToolEngine",
    "ChatWebSearchServerToolParameters",
    "ChatWebSearchServerToolParametersType",
    "ChatWebSearchServerToolParametersTypedDict",
    "ChatWebSearchServerToolSearchContextSize",
    "ChatWebSearchServerToolTypeOpenrouterWebSearch",
    "ChatWebSearchServerToolTypedDict",
    "ChatWebSearchServerToolUserLocation",
    "ChatWebSearchServerToolUserLocationTypedDict",
    "ChatWebSearchShorthand",
    "ChatWebSearchShorthandEngine",
    "ChatWebSearchShorthandParameters",
    "ChatWebSearchShorthandParametersEngine",
    "ChatWebSearchShorthandParametersSearchContextSize",
    "ChatWebSearchShorthandParametersType",
    "ChatWebSearchShorthandParametersTypedDict",
    "ChatWebSearchShorthandParametersUserLocation",
    "ChatWebSearchShorthandParametersUserLocationTypedDict",
    "ChatWebSearchShorthandSearchContextSize",
    "ChatWebSearchShorthandType",
    "ChatWebSearchShorthandTypeApproximate",
    "ChatWebSearchShorthandTypedDict",
    "ChatWebSearchShorthandUserLocation",
    "ChatWebSearchShorthandUserLocationTypedDict",
    "Code",
    "CodeInterpreterServerTool",
    "CodeInterpreterServerToolTypedDict",
    "CodexLocalShellTool",
    "CodexLocalShellToolType",
    "CodexLocalShellToolTypedDict",
    "CompletionTokensDetails",
    "CompletionTokensDetailsTypedDict",
    "CompoundFilter",
    "CompoundFilterType",
    "CompoundFilterTypedDict",
    "ComputerUseServerTool",
    "ComputerUseServerToolType",
    "ComputerUseServerToolTypedDict",
    "ConflictResponseErrorData",
    "ConflictResponseErrorDataTypedDict",
    "ConnectorID",
    "Container",
    "ContainerAuto",
    "ContainerAutoTypedDict",
    "ContainerType",
    "ContainerTypedDict",
    "ContentPartAddedEvent",
    "ContentPartAddedEventPart",
    "ContentPartAddedEventPartTypedDict",
    "ContentPartAddedEventType",
    "ContentPartAddedEventTypedDict",
    "ContentPartDoneEvent",
    "ContentPartDoneEventPart",
    "ContentPartDoneEventPartTypedDict",
    "ContentPartDoneEventType",
    "ContentPartDoneEventTypedDict",
    "ContextCompressionEngine",
    "CostDetails",
    "CostDetailsTypedDict",
    "CreateChargeRequest",
    "CreateChargeRequestTypedDict",
    "CustomTool",
    "CustomToolTypedDict",
    "Data",
    "DataCollection",
    "DataTypedDict",
    "DatetimeServerTool",
    "DatetimeServerToolParameters",
    "DatetimeServerToolParametersTypedDict",
    "DatetimeServerToolType",
    "DatetimeServerToolTypedDict",
    "DefaultParameters",
    "DefaultParametersTypedDict",
    "EasyInputMessage",
    "EasyInputMessageContentInputImage",
    "EasyInputMessageContentInputImageTypedDict",
    "EasyInputMessageContentType",
    "EasyInputMessageContentUnion1",
    "EasyInputMessageContentUnion1TypedDict",
    "EasyInputMessageContentUnion2",
    "EasyInputMessageContentUnion2TypedDict",
    "EasyInputMessageDetail",
    "EasyInputMessagePhaseCommentary",
    "EasyInputMessagePhaseFinalAnswer",
    "EasyInputMessagePhaseUnion",
    "EasyInputMessagePhaseUnionTypedDict",
    "EasyInputMessageRoleAssistant",
    "EasyInputMessageRoleDeveloper",
    "EasyInputMessageRoleSystem",
    "EasyInputMessageRoleUnion",
    "EasyInputMessageRoleUnionTypedDict",
    "EasyInputMessageRoleUser",
    "EasyInputMessageTypeMessage",
    "EasyInputMessageTypedDict",
    "EdgeNetworkTimeoutResponseErrorData",
    "EdgeNetworkTimeoutResponseErrorDataTypedDict",
    "Effort",
    "EndpointStatus",
    "Environment",
    "Error",
    "ErrorEvent",
    "ErrorEventType",
    "ErrorEventTypedDict",
    "ErrorTypedDict",
    "File",
    "FileCitation",
    "FileCitationType",
    "FileCitationTypedDict",
    "FilePath",
    "FilePathType",
    "FilePathTypedDict",
    "FileSearchServerTool",
    "FileSearchServerToolFilters",
    "FileSearchServerToolFiltersTypedDict",
    "FileSearchServerToolTypedDict",
    "FileTypedDict",
    "Filters",
    "FiltersType",
    "FiltersTypedDict",
    "ForbiddenResponseErrorData",
    "ForbiddenResponseErrorDataTypedDict",
    "Format",
    "FormatGrammar",
    "FormatGrammarTypedDict",
    "FormatJSONObjectConfig",
    "FormatJSONObjectConfigType",
    "FormatJSONObjectConfigTypedDict",
    "FormatJSONSchemaConfig",
    "FormatJSONSchemaConfigType",
    "FormatJSONSchemaConfigTypedDict",
    "FormatText",
    "FormatTextConfig",
    "FormatTextConfigType",
    "FormatTextConfigTypedDict",
    "FormatTextTypedDict",
    "FormatTypeGrammar",
    "FormatTypeText",
    "FormatTypedDict",
    "Formats",
    "FormatsTypedDict",
    "FunctionCallArgsDeltaEvent",
    "FunctionCallArgsDeltaEventType",
    "FunctionCallArgsDeltaEventTypedDict",
    "FunctionCallArgsDoneEvent",
    "FunctionCallArgsDoneEventType",
    "FunctionCallArgsDoneEventTypedDict",
    "FunctionCallItem",
    "FunctionCallItemType",
    "FunctionCallItemTypedDict",
    "FunctionCallOutputItem",
    "FunctionCallOutputItemDetail",
    "FunctionCallOutputItemOutputUnion1",
    "FunctionCallOutputItemOutputUnion1TypedDict",
    "FunctionCallOutputItemOutputUnion2",
    "FunctionCallOutputItemOutputUnion2TypedDict",
    "FunctionCallOutputItemTypeFunctionCallOutput",
    "FunctionCallOutputItemTypedDict",
    "ImageGenCallCompletedEvent",
    "ImageGenCallCompletedEventType",
    "ImageGenCallCompletedEventTypedDict",
    "ImageGenCallGeneratingEvent",
    "ImageGenCallGeneratingEventType",
    "ImageGenCallGeneratingEventTypedDict",
    "ImageGenCallInProgressEvent",
    "ImageGenCallInProgressEventType",
    "ImageGenCallInProgressEventTypedDict",
    "ImageGenCallPartialImageEvent",
    "ImageGenCallPartialImageEventType",
    "ImageGenCallPartialImageEventTypedDict",
    "ImageGenerationServerTool",
    "ImageGenerationServerToolType",
    "ImageGenerationServerToolTypedDict",
    "ImageGenerationStatus",
    "IncompleteDetails",
    "IncompleteDetailsTypedDict",
    "InputAudio",
    "InputAudioFormat",
    "InputAudioInputAudio",
    "InputAudioInputAudioTypedDict",
    "InputAudioType",
    "InputAudioTypedDict",
    "InputFidelity",
    "InputFile",
    "InputFileType",
    "InputFileTypedDict",
    "InputImage",
    "InputImageDetail",
    "InputImageMask",
    "InputImageMaskTypedDict",
    "InputImageType",
    "InputImageTypedDict",
    "InputMessageItem",
    "InputMessageItemContentInputImage",
    "InputMessageItemContentInputImageTypedDict",
    "InputMessageItemContentType",
    "InputMessageItemContentUnion",
    "InputMessageItemContentUnionTypedDict",
    "InputMessageItemDetail",
    "InputMessageItemRoleDeveloper",
    "InputMessageItemRoleSystem",
    "InputMessageItemRoleUnion",
    "InputMessageItemRoleUnionTypedDict",
    "InputMessageItemRoleUser",
    "InputMessageItemTypeMessage",
    "InputMessageItemTypedDict",
    "InputModality",
    "InputText",
    "InputTextType",
    "InputTextTypedDict",
    "InputTokensDetails",
    "InputTokensDetailsTypedDict",
    "InputVideo",
    "InputVideoType",
    "InputVideoTypedDict",
    "InputsContent1",
    "InputsContent1TypedDict",
    "InputsContent2",
    "InputsContent2TypedDict",
    "InputsFormat",
    "InputsMessage",
    "InputsMessageTypedDict",
    "InputsPhaseCommentary",
    "InputsPhaseFinalAnswer",
    "InputsPhaseUnion",
    "InputsPhaseUnionTypedDict",
    "InputsReasoning",
    "InputsReasoningTypedDict",
    "InputsRole",
    "InputsStatusCompleted1",
    "InputsStatusCompleted2",
    "InputsStatusInProgress1",
    "InputsStatusInProgress2",
    "InputsStatusIncomplete1",
    "InputsStatusIncomplete2",
    "InputsStatusUnion1",
    "InputsStatusUnion1TypedDict",
    "InputsStatusUnion2",
    "InputsStatusUnion2TypedDict",
    "InputsTypeMessage",
    "InputsTypeReasoning",
    "InputsUnion",
    "InputsUnion1",
    "InputsUnion1TypedDict",
    "InputsUnionTypedDict",
    "InstructType",
    "InternalServerResponseErrorData",
    "InternalServerResponseErrorDataTypedDict",
    "LegacyChatContentVideo",
    "LegacyChatContentVideoType",
    "LegacyChatContentVideoTypedDict",
    "LegacyWebSearchServerTool",
    "LegacyWebSearchServerToolEngine",
    "LegacyWebSearchServerToolFilters",
    "LegacyWebSearchServerToolFiltersTypedDict",
    "LegacyWebSearchServerToolType",
    "LegacyWebSearchServerToolTypedDict",
    "ListEndpointsResponse",
    "ListEndpointsResponseTypedDict",
    "McpServerTool",
    "McpServerToolType",
    "McpServerToolTypedDict",
    "MemoryLimit",
    "Modality",
    "Model",
    "ModelArchitecture",
    "ModelArchitectureInstructType",
    "ModelArchitectureTypedDict",
    "ModelEnum",
    "ModelGroup",
    "ModelTypedDict",
    "ModelsCountResponse",
    "ModelsCountResponseTypedDict",
    "ModelsListResponse",
    "ModelsListResponseTypedDict",
    "Moderation",
    "Never",
    "NeverTypedDict",
    "NotFoundResponseErrorData",
    "NotFoundResponseErrorDataTypedDict",
    "OpenAIResponsesAnnotation",
    "OpenAIResponsesAnnotationTypedDict",
    "OpenAIResponsesRefusalContent",
    "OpenAIResponsesRefusalContentType",
    "OpenAIResponsesRefusalContentTypedDict",
    "OpenAIResponsesResponseStatus",
    "OpenAIResponsesToolChoice",
    "OpenAIResponsesToolChoiceAuto",
    "OpenAIResponsesToolChoiceFunction",
    "OpenAIResponsesToolChoiceFunctionTypedDict",
    "OpenAIResponsesToolChoiceNone",
    "OpenAIResponsesToolChoiceRequired",
    "OpenAIResponsesToolChoiceTypeFunction",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview20250311",
    "OpenAIResponsesToolChoiceTypedDict",
    "OpenAIResponsesToolChoiceUnion",
    "OpenAIResponsesToolChoiceUnionTypedDict",
    "OpenAIResponsesTruncation",
    "OpenResponsesResult",
    "OpenResponsesResultObject",
    "OpenResponsesResultToolFunction",
    "OpenResponsesResultToolFunctionTypedDict",
    "OpenResponsesResultToolUnion",
    "OpenResponsesResultToolUnionTypedDict",
    "OpenResponsesResultType",
    "OpenResponsesResultTypedDict",
    "OutputDatetimeItem",
    "OutputDatetimeItemStatus",
    "OutputDatetimeItemType",
    "OutputDatetimeItemTypedDict",
    "OutputFileSearchCallItem",
    "OutputFileSearchCallItemType",
    "OutputFileSearchCallItemTypedDict",
    "OutputFormat",
    "OutputFunctionCallItem",
    "OutputFunctionCallItemStatusCompleted",
    "OutputFunctionCallItemStatusInProgress",
    "OutputFunctionCallItemStatusIncomplete",
    "OutputFunctionCallItemStatusUnion",
    "OutputFunctionCallItemStatusUnionTypedDict",
    "OutputFunctionCallItemType",
    "OutputFunctionCallItemTypedDict",
    "OutputImageGenerationCallItem",
    "OutputImageGenerationCallItemType",
    "OutputImageGenerationCallItemTypedDict",
    "OutputInputImage",
    "OutputInputImageTypedDict",
    "OutputItemImageGenerationCall",
    "OutputItemImageGenerationCallType",
    "OutputItemImageGenerationCallTypedDict",
    "OutputItems",
    "OutputItemsTypedDict",
    "OutputMessage",
    "OutputMessageContent",
    "OutputMessageContentTypedDict",
    "OutputMessageItem",
    "OutputMessageItemContent",
    "OutputMessageItemContentTypedDict",
    "OutputMessageItemPhaseCommentary",
    "OutputMessageItemPhaseFinalAnswer",
    "OutputMessageItemPhaseUnion",
    "OutputMessageItemPhaseUnionTypedDict",
    "OutputMessageItemRole",
    "OutputMessageItemStatusCompleted",
    "OutputMessageItemStatusInProgress",
    "OutputMessageItemStatusIncomplete",
    "OutputMessageItemStatusUnion",
    "OutputMessageItemStatusUnionTypedDict",
    "OutputMessageItemType",
    "OutputMessageItemTypedDict",
    "OutputMessagePhaseCommentary",
    "OutputMessagePhaseFinalAnswer",
    "OutputMessagePhaseUnion",
    "OutputMessagePhaseUnionTypedDict",
    "OutputMessageRole",
    "OutputMessageStatusCompleted",
    "OutputMessageStatusInProgress",
    "OutputMessageStatusIncomplete",
    "OutputMessageStatusUnion",
    "OutputMessageStatusUnionTypedDict",
    "OutputMessageType",
    "OutputMessageTypedDict",
    "OutputModality",
    "OutputModalityEnum",
    "OutputReasoningItem",
    "OutputReasoningItemFormat",
    "OutputReasoningItemStatusCompleted",
    "OutputReasoningItemStatusInProgress",
    "OutputReasoningItemStatusIncomplete",
    "OutputReasoningItemStatusUnion",
    "OutputReasoningItemStatusUnionTypedDict",
    "OutputReasoningItemType",
    "OutputReasoningItemTypedDict",
    "OutputServerToolItem",
    "OutputServerToolItemStatus",
    "OutputServerToolItemTypedDict",
    "OutputTokensDetails",
    "OutputTokensDetailsTypedDict",
    "OutputType",
    "OutputWebSearchCallItem",
    "OutputWebSearchCallItemTypedDict",
    "PDFParserEngine",
    "PDFParserEngineEnum",
    "PDFParserEnginePDFText",
    "PDFParserEngineTypedDict",
    "PDFParserOptions",
    "PDFParserOptionsTypedDict",
    "Parameter",
    "Partition",
    "PayloadTooLargeResponseErrorData",
    "PayloadTooLargeResponseErrorDataTypedDict",
    "PaymentRequiredResponseErrorData",
    "PaymentRequiredResponseErrorDataTypedDict",
    "PerRequestLimits",
    "PerRequestLimitsTypedDict",
    "PercentileLatencyCutoffs",
    "PercentileLatencyCutoffsTypedDict",
    "PercentileStats",
    "PercentileStatsTypedDict",
    "PercentileThroughputCutoffs",
    "PercentileThroughputCutoffsTypedDict",
    "PreferredMaxLatency",
    "PreferredMaxLatencyTypedDict",
    "PreferredMinThroughput",
    "PreferredMinThroughputTypedDict",
    "Preview20250311WebSearchServerTool",
    "Preview20250311WebSearchServerToolEngine",
    "Preview20250311WebSearchServerToolFilters",
    "Preview20250311WebSearchServerToolFiltersTypedDict",
    "Preview20250311WebSearchServerToolType",
    "Preview20250311WebSearchServerToolTypedDict",
    "PreviewWebSearchServerTool",
    "PreviewWebSearchServerToolEngine",
    "PreviewWebSearchServerToolFilters",
    "PreviewWebSearchServerToolFiltersTypedDict",
    "PreviewWebSearchServerToolType",
    "PreviewWebSearchServerToolTypedDict",
    "PreviewWebSearchUserLocation",
    "PreviewWebSearchUserLocationType",
    "PreviewWebSearchUserLocationTypedDict",
    "Pricing",
    "PricingTypedDict",
    "PromptTokensDetails",
    "PromptTokensDetailsTypedDict",
    "ProviderName",
    "ProviderOverloadedResponseErrorData",
    "ProviderOverloadedResponseErrorDataTypedDict",
    "ProviderPreferences",
    "ProviderPreferencesBy",
    "ProviderPreferencesIgnore",
    "ProviderPreferencesIgnoreTypedDict",
    "ProviderPreferencesMaxPrice",
    "ProviderPreferencesMaxPriceTypedDict",
    "ProviderPreferencesOnly",
    "ProviderPreferencesOnlyTypedDict",
    "ProviderPreferencesOrder",
    "ProviderPreferencesOrderTypedDict",
    "ProviderPreferencesPartition",
    "ProviderPreferencesProviderSort",
    "ProviderPreferencesProviderSortConfig",
    "ProviderPreferencesProviderSortConfigEnum",
    "ProviderPreferencesProviderSortConfigTypedDict",
    "ProviderPreferencesProviderSortConfigUnion",
    "ProviderPreferencesProviderSortConfigUnionTypedDict",
    "ProviderPreferencesSortEnum",
    "ProviderPreferencesSortUnion",
    "ProviderPreferencesSortUnionTypedDict",
    "ProviderPreferencesTypedDict",
    "ProviderSort",
    "ProviderSortConfig",
    "ProviderSortConfigTypedDict",
    "PublicEndpoint",
    "PublicEndpointQuantization",
    "PublicEndpointTypedDict",
    "PublicPricing",
    "PublicPricingTypedDict",
    "Quality",
    "Quantization",
    "Ranker",
    "RankingOptions",
    "RankingOptionsTypedDict",
    "Reason",
    "Reasoning",
    "ReasoningConfig",
    "ReasoningConfigTypedDict",
    "ReasoningDeltaEvent",
    "ReasoningDeltaEventType",
    "ReasoningDeltaEventTypedDict",
    "ReasoningDetailEncrypted",
    "ReasoningDetailEncryptedFormat",
    "ReasoningDetailEncryptedType",
    "ReasoningDetailEncryptedTypedDict",
    "ReasoningDetailSummary",
    "ReasoningDetailSummaryFormat",
    "ReasoningDetailSummaryType",
    "ReasoningDetailSummaryTypedDict",
    "ReasoningDetailText",
    "ReasoningDetailTextFormat",
    "ReasoningDetailTextType",
    "ReasoningDetailTextTypedDict",
    "ReasoningDetailUnion",
    "ReasoningDetailUnionTypedDict",
    "ReasoningDoneEvent",
    "ReasoningDoneEventType",
    "ReasoningDoneEventTypedDict",
    "ReasoningEffortEnum",
    "ReasoningItem",
    "ReasoningItemFormat",
    "ReasoningItemStatusCompleted",
    "ReasoningItemStatusInProgress",
    "ReasoningItemStatusIncomplete",
    "ReasoningItemStatusUnion",
    "ReasoningItemStatusUnionTypedDict",
    "ReasoningItemType",
    "ReasoningItemTypedDict",
    "ReasoningSummaryPartAddedEvent",
    "ReasoningSummaryPartAddedEventType",
    "ReasoningSummaryPartAddedEventTypedDict",
    "ReasoningSummaryPartDoneEvent",
    "ReasoningSummaryPartDoneEventType",
    "ReasoningSummaryPartDoneEventTypedDict",
    "ReasoningSummaryText",
    "ReasoningSummaryTextDeltaEvent",
    "ReasoningSummaryTextDeltaEventType",
    "ReasoningSummaryTextDeltaEventTypedDict",
    "ReasoningSummaryTextDoneEvent",
    "ReasoningSummaryTextDoneEventType",
    "ReasoningSummaryTextDoneEventTypedDict",
    "ReasoningSummaryTextType",
    "ReasoningSummaryTextTypedDict",
    "ReasoningSummaryVerbosityEnum",
    "ReasoningTextContent",
    "ReasoningTextContentType",
    "ReasoningTextContentTypedDict",
    "ReasoningTypedDict",
    "RefusalDeltaEvent",
    "RefusalDeltaEventType",
    "RefusalDeltaEventTypedDict",
    "RefusalDoneEvent",
    "RefusalDoneEventType",
    "RefusalDoneEventTypedDict",
    "RequestTimeoutResponseErrorData",
    "RequestTimeoutResponseErrorDataTypedDict",
    "RequireApproval",
    "RequireApprovalAlways",
    "RequireApprovalNever",
    "RequireApprovalTypedDict",
    "ResponseFormat",
    "ResponseFormatTypedDict",
    "ResponseIncludesEnum",
    "ResponseOutputText",
    "ResponseOutputTextLogprob",
    "ResponseOutputTextLogprobTypedDict",
    "ResponseOutputTextTopLogprob",
    "ResponseOutputTextTopLogprobTypedDict",
    "ResponseOutputTextType",
    "ResponseOutputTextTypedDict",
    "ResponsesErrorField",
    "ResponsesErrorFieldTypedDict",
    "ResponsesRequest",
    "ResponsesRequestIDAutoRouter",
    "ResponsesRequestIDContextCompression",
    "ResponsesRequestIDFileParser",
    "ResponsesRequestIDModeration",
    "ResponsesRequestIDResponseHealing",
    "ResponsesRequestIDWeb",
    "ResponsesRequestIgnore",
    "ResponsesRequestIgnoreTypedDict",
    "ResponsesRequestImageConfig",
    "ResponsesRequestImageConfigTypedDict",
    "ResponsesRequestMaxPrice",
    "ResponsesRequestMaxPriceTypedDict",
    "ResponsesRequestOnly",
    "ResponsesRequestOnlyTypedDict",
    "ResponsesRequestOrder",
    "ResponsesRequestOrderTypedDict",
    "ResponsesRequestPluginAutoRouter",
    "ResponsesRequestPluginAutoRouterTypedDict",
    "ResponsesRequestPluginContextCompression",
    "ResponsesRequestPluginContextCompressionTypedDict",
    "ResponsesRequestPluginFileParser",
    "ResponsesRequestPluginFileParserTypedDict",
    "ResponsesRequestPluginModeration",
    "ResponsesRequestPluginModerationTypedDict",
    "ResponsesRequestPluginResponseHealing",
    "ResponsesRequestPluginResponseHealingTypedDict",
    "ResponsesRequestPluginUnion",
    "ResponsesRequestPluginUnionTypedDict",
    "ResponsesRequestPluginWeb",
    "ResponsesRequestPluginWebTypedDict",
    "ResponsesRequestProvider",
    "ResponsesRequestProviderTypedDict",
    "ResponsesRequestServiceTier",
    "ResponsesRequestSort",
    "ResponsesRequestSortTypedDict",
    "ResponsesRequestToolFunction",
    "ResponsesRequestToolFunctionTypedDict",
    "ResponsesRequestToolUnion",
    "ResponsesRequestToolUnionTypedDict",
    "ResponsesRequestTrace",
    "ResponsesRequestTraceTypedDict",
    "ResponsesRequestType",
    "ResponsesRequestTypedDict",
    "SearchContextSizeEnum",
    "Security",
    "SecurityTypedDict",
    "ServiceUnavailableResponseErrorData",
    "ServiceUnavailableResponseErrorDataTypedDict",
    "ShellServerTool",
    "ShellServerToolType",
    "ShellServerToolTypedDict",
    "Size",
    "Source",
    "SourceTypedDict",
    "Stop",
    "StopTypedDict",
    "StoredPromptTemplate",
    "StoredPromptTemplateTypedDict",
    "StreamEvents",
    "StreamEventsResponseCompleted",
    "StreamEventsResponseCompletedTypedDict",
    "StreamEventsResponseCreated",
    "StreamEventsResponseCreatedTypedDict",
    "StreamEventsResponseFailed",
    "StreamEventsResponseFailedTypedDict",
    "StreamEventsResponseInProgress",
    "StreamEventsResponseInProgressTypedDict",
    "StreamEventsResponseIncomplete",
    "StreamEventsResponseIncompleteTypedDict",
    "StreamEventsResponseOutputItemAdded",
    "StreamEventsResponseOutputItemAddedTypedDict",
    "StreamEventsResponseOutputItemDone",
    "StreamEventsResponseOutputItemDoneTypedDict",
    "StreamEventsTypedDict",
    "Syntax",
    "TextConfig",
    "TextConfigTypedDict",
    "TextConfigVerbosity",
    "TextDeltaEvent",
    "TextDeltaEventLogprob",
    "TextDeltaEventLogprobTypedDict",
    "TextDeltaEventTopLogprob",
    "TextDeltaEventTopLogprobTypedDict",
    "TextDeltaEventType",
    "TextDeltaEventTypedDict",
    "TextDoneEvent",
    "TextDoneEventLogprob",
    "TextDoneEventLogprobTypedDict",
    "TextDoneEventTopLogprob",
    "TextDoneEventTopLogprobTypedDict",
    "TextDoneEventType",
    "TextDoneEventTypedDict",
    "TextExtendedConfig",
    "TextExtendedConfigTypedDict",
    "TextExtendedConfigVerbosity",
    "Tokenizer",
    "TooManyRequestsResponseErrorData",
    "TooManyRequestsResponseErrorDataTypedDict",
    "ToolCallStatusEnum",
    "TopProviderInfo",
    "TopProviderInfoTypedDict",
    "TruncationEnum",
    "Type",
    "TypeCodeInterpreter",
    "TypeCustom",
    "TypeFileSearch",
    "TypeFindInPage",
    "TypeOpenPage",
    "TypeResponseCompleted",
    "TypeResponseCreated",
    "TypeResponseFailed",
    "TypeResponseInProgress",
    "TypeResponseIncomplete",
    "TypeResponseOutputItemAdded",
    "TypeResponseOutputItemDone",
    "TypeSearch",
    "TypeTypedDict",
    "TypeURL",
    "TypeWebSearchCall",
    "URLCitation",
    "URLCitationType",
    "URLCitationTypedDict",
    "UnauthorizedResponseErrorData",
    "UnauthorizedResponseErrorDataTypedDict",
    "UnprocessableEntityResponseErrorData",
    "UnprocessableEntityResponseErrorDataTypedDict",
    "Usage",
    "UsageTypedDict",
    "Value1",
    "Value1TypedDict",
    "Value2",
    "Value2TypedDict",
    "Variables",
    "VariablesTypedDict",
    "WebSearchCallCompletedEvent",
    "WebSearchCallCompletedEventType",
    "WebSearchCallCompletedEventTypedDict",
    "WebSearchCallInProgressEvent",
    "WebSearchCallInProgressEventType",
    "WebSearchCallInProgressEventTypedDict",
    "WebSearchCallSearchingEvent",
    "WebSearchCallSearchingEventType",
    "WebSearchCallSearchingEventTypedDict",
    "WebSearchEngine",
    "WebSearchServerTool",
    "WebSearchServerToolEngine",
    "WebSearchServerToolFilters",
    "WebSearchServerToolFiltersTypedDict",
    "WebSearchServerToolOpenRouter",
    "WebSearchServerToolOpenRouterParameters",
    "WebSearchServerToolOpenRouterParametersTypedDict",
    "WebSearchServerToolOpenRouterType",
    "WebSearchServerToolOpenRouterTypedDict",
    "WebSearchServerToolType",
    "WebSearchServerToolTypedDict",
    "WebSearchStatus",
    "WebSearchUserLocation",
    "WebSearchUserLocationType",
    "WebSearchUserLocationTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "ActivityItem": ".activityitem",
    "ActivityItemTypedDict": ".activityitem",
    "AnnotationAddedEvent": ".annotationaddedevent",
    "AnnotationAddedEventType": ".annotationaddedevent",
    "AnnotationAddedEventTypedDict": ".annotationaddedevent",
    "ApplyPatchServerTool": ".applypatchservertool",
    "ApplyPatchServerToolType": ".applypatchservertool",
    "ApplyPatchServerToolTypedDict": ".applypatchservertool",
    "BadGatewayResponseErrorData": ".badgatewayresponseerrordata",
    "BadGatewayResponseErrorDataTypedDict": ".badgatewayresponseerrordata",
    "BadRequestResponseErrorData": ".badrequestresponseerrordata",
    "BadRequestResponseErrorDataTypedDict": ".badrequestresponseerrordata",
    "BaseInputsContent1": ".baseinputs_union",
    "BaseInputsContent1TypedDict": ".baseinputs_union",
    "BaseInputsContent2": ".baseinputs_union",
    "BaseInputsContent2TypedDict": ".baseinputs_union",
    "BaseInputsContent3": ".baseinputs_union",
    "BaseInputsContent3TypedDict": ".baseinputs_union",
    "BaseInputsFunctionCall": ".baseinputs_union",
    "BaseInputsFunctionCallOutput": ".baseinputs_union",
    "BaseInputsFunctionCallOutputTypedDict": ".baseinputs_union",
    "BaseInputsFunctionCallTypedDict": ".baseinputs_union",
    "BaseInputsMessage1": ".baseinputs_union",
    "BaseInputsMessage1TypedDict": ".baseinputs_union",
    "BaseInputsMessage2": ".baseinputs_union",
    "BaseInputsMessage2TypedDict": ".baseinputs_union",
    "BaseInputsOutput1": ".baseinputs_union",
    "BaseInputsOutput1TypedDict": ".baseinputs_union",
    "BaseInputsOutput2": ".baseinputs_union",
    "BaseInputsOutput2TypedDict": ".baseinputs_union",
    "BaseInputsPhaseCommentary": ".baseinputs_union",
    "BaseInputsPhaseFinalAnswer": ".baseinputs_union",
    "BaseInputsPhaseUnion": ".baseinputs_union",
    "BaseInputsPhaseUnionTypedDict": ".baseinputs_union",
    "BaseInputsRoleAssistant": ".baseinputs_union",
    "BaseInputsRoleDeveloper1": ".baseinputs_union",
    "BaseInputsRoleDeveloper2": ".baseinputs_union",
    "BaseInputsRoleSystem1": ".baseinputs_union",
    "BaseInputsRoleSystem2": ".baseinputs_union",
    "BaseInputsRoleUnion1": ".baseinputs_union",
    "BaseInputsRoleUnion1TypedDict": ".baseinputs_union",
    "BaseInputsRoleUnion2": ".baseinputs_union",
    "BaseInputsRoleUnion2TypedDict": ".baseinputs_union",
    "BaseInputsRoleUser1": ".baseinputs_union",
    "BaseInputsRoleUser2": ".baseinputs_union",
    "BaseInputsTypeFunctionCall": ".baseinputs_union",
    "BaseInputsTypeFunctionCallOutput": ".baseinputs_union",
    "BaseInputsTypeMessage1": ".baseinputs_union",
    "BaseInputsTypeMessage2": ".baseinputs_union",
    "BaseInputsUnion": ".baseinputs_union",
    "BaseInputsUnion1": ".baseinputs_union",
    "BaseInputsUnion1TypedDict": ".baseinputs_union",
    "BaseInputsUnionTypedDict": ".baseinputs_union",
    "BaseReasoningConfig": ".basereasoningconfig",
    "BaseReasoningConfigTypedDict": ".basereasoningconfig",
    "ChatAssistantImages": ".chatassistantimages",
    "ChatAssistantImagesImageURL": ".chatassistantimages",
    "ChatAssistantImagesImageURLTypedDict": ".chatassistantimages",
    "ChatAssistantImagesTypedDict": ".chatassistantimages",
    "ChatAssistantMessage": ".chatassistantmessage",
    "ChatAssistantMessageContent": ".chatassistantmessage",
    "ChatAssistantMessageContentTypedDict": ".chatassistantmessage",
    "ChatAssistantMessageRole": ".chatassistantmessage",
    "ChatAssistantMessageTypedDict": ".chatassistantmessage",
    "ChatAudioOutput": ".chataudiooutput",
    "ChatAudioOutputTypedDict": ".chataudiooutput",
    "ChatChoice": ".chatchoice",
    "ChatChoiceTypedDict": ".chatchoice",
    "ChatContentAudio": ".chatcontentaudio",
    "ChatContentAudioInputAudio": ".chatcontentaudio",
    "ChatContentAudioInputAudioTypedDict": ".chatcontentaudio",
    "ChatContentAudioType": ".chatcontentaudio",
    "ChatContentAudioTypedDict": ".chatcontentaudio",
    "ChatContentCacheControl": ".chatcontentcachecontrol",
    "ChatContentCacheControlTTL": ".chatcontentcachecontrol",
    "ChatContentCacheControlType": ".chatcontentcachecontrol",
    "ChatContentCacheControlTypedDict": ".chatcontentcachecontrol",
    "ChatContentFile": ".chatcontentfile",
    "ChatContentFileType": ".chatcontentfile",
    "ChatContentFileTypedDict": ".chatcontentfile",
    "File": ".chatcontentfile",
    "FileTypedDict": ".chatcontentfile",
    "ChatContentImage": ".chatcontentimage",
    "ChatContentImageDetail": ".chatcontentimage",
    "ChatContentImageImageURL": ".chatcontentimage",
    "ChatContentImageImageURLTypedDict": ".chatcontentimage",
    "ChatContentImageType": ".chatcontentimage",
    "ChatContentImageTypedDict": ".chatcontentimage",
    "ChatContentItems": ".chatcontentitems",
    "ChatContentItems1": ".chatcontentitems",
    "ChatContentItems1TypedDict": ".chatcontentitems",
    "ChatContentItemsTypedDict": ".chatcontentitems",
    "ChatContentText": ".chatcontenttext",
    "ChatContentTextType": ".chatcontenttext",
    "ChatContentTextTypedDict": ".chatcontenttext",
    "ChatContentVideo": ".chatcontentvideo",
    "ChatContentVideoType": ".chatcontentvideo",
    "ChatContentVideoTypedDict": ".chatcontentvideo",
    "ChatContentVideoInput": ".chatcontentvideoinput",
    "ChatContentVideoInputTypedDict": ".chatcontentvideoinput",
    "ChatDebugOptions": ".chatdebugoptions",
    "ChatDebugOptionsTypedDict": ".chatdebugoptions",
    "ChatDeveloperMessage": ".chatdevelopermessage",
    "ChatDeveloperMessageContent": ".chatdevelopermessage",
    "ChatDeveloperMessageContentTypedDict": ".chatdevelopermessage",
    "ChatDeveloperMessageRole": ".chatdevelopermessage",
    "ChatDeveloperMessageTypedDict": ".chatdevelopermessage",
    "ChatFinishReasonEnum": ".chatfinishreasonenum",
    "ChatFormatGrammarConfig": ".chatformatgrammarconfig",
    "ChatFormatGrammarConfigType": ".chatformatgrammarconfig",
    "ChatFormatGrammarConfigTypedDict": ".chatformatgrammarconfig",
    "ChatFormatJSONSchemaConfig": ".chatformatjsonschemaconfig",
    "ChatFormatJSONSchemaConfigType": ".chatformatjsonschemaconfig",
    "ChatFormatJSONSchemaConfigTypedDict": ".chatformatjsonschemaconfig",
    "ChatFormatPythonConfig": ".chatformatpythonconfig",
    "ChatFormatPythonConfigType": ".chatformatpythonconfig",
    "ChatFormatPythonConfigTypedDict": ".chatformatpythonconfig",
    "ChatFormatTextConfig": ".chatformattextconfig",
    "ChatFormatTextConfigType": ".chatformattextconfig",
    "ChatFormatTextConfigTypedDict": ".chatformattextconfig",
    "ChatFunctionTool": ".chatfunctiontool",
    "ChatFunctionToolFunction": ".chatfunctiontool",
    "ChatFunctionToolFunctionFunction": ".chatfunctiontool",
    "ChatFunctionToolFunctionFunctionTypedDict": ".chatfunctiontool",
    "ChatFunctionToolFunctionTypedDict": ".chatfunctiontool",
    "ChatFunctionToolType": ".chatfunctiontool",
    "ChatFunctionToolTypedDict": ".chatfunctiontool",
    "ChatJSONSchemaConfig": ".chatjsonschemaconfig",
    "ChatJSONSchemaConfigTypedDict": ".chatjsonschemaconfig",
    "ChatMessages": ".chatmessages",
    "ChatMessagesTypedDict": ".chatmessages",
    "ChatNamedToolChoice": ".chatnamedtoolchoice",
    "ChatNamedToolChoiceFunction": ".chatnamedtoolchoice",
    "ChatNamedToolChoiceFunctionTypedDict": ".chatnamedtoolchoice",
    "ChatNamedToolChoiceType": ".chatnamedtoolchoice",
    "ChatNamedToolChoiceTypedDict": ".chatnamedtoolchoice",
    "ChatReasoningSummaryVerbosityEnum": ".chatreasoningsummaryverbosityenum",
    "CacheControl": ".chatrequest",
    "CacheControlTypedDict": ".chatrequest",
    "ChatRequest": ".chatrequest",
    "ChatRequestBy": ".chatrequest",
    "ChatRequestIDAutoRouter": ".chatrequest",
    "ChatRequestIDContextCompression": ".chatrequest",
    "ChatRequestIDFileParser": ".chatrequest",
    "ChatRequestIDModeration": ".chatrequest",
    "ChatRequestIDResponseHealing": ".chatrequest",
    "ChatRequestIDWeb": ".chatrequest",
    "ChatRequestIgnore": ".chatrequest",
    "ChatRequestIgnoreTypedDict": ".chatrequest",
    "ChatRequestImageConfig": ".chatrequest",
    "ChatRequestImageConfigTypedDict": ".chatrequest",
    "ChatRequestMaxPrice": ".chatrequest",
    "ChatRequestMaxPriceTypedDict": ".chatrequest",
    "ChatRequestOnly": ".chatrequest",
    "ChatRequestOnlyTypedDict": ".chatrequest",
    "ChatRequestOrder": ".chatrequest",
    "ChatRequestOrderTypedDict": ".chatrequest",
    "ChatRequestPartition": ".chatrequest",
    "ChatRequestPluginAutoRouter": ".chatrequest",
    "ChatRequestPluginAutoRouterTypedDict": ".chatrequest",
    "ChatRequestPluginContextCompression": ".chatrequest",
    "ChatRequestPluginContextCompressionTypedDict": ".chatrequest",
    "ChatRequestPluginFileParser": ".chatrequest",
    "ChatRequestPluginFileParserTypedDict": ".chatrequest",
    "ChatRequestPluginModeration": ".chatrequest",
    "ChatRequestPluginModerationTypedDict": ".chatrequest",
    "ChatRequestPluginResponseHealing": ".chatrequest",
    "ChatRequestPluginResponseHealingTypedDict": ".chatrequest",
    "ChatRequestPluginUnion": ".chatrequest",
    "ChatRequestPluginUnionTypedDict": ".chatrequest",
    "ChatRequestPluginWeb": ".chatrequest",
    "ChatRequestPluginWebTypedDict": ".chatrequest",
    "ChatRequestProvider": ".chatrequest",
    "ChatRequestProviderSort": ".chatrequest",
    "ChatRequestProviderSortConfig": ".chatrequest",
    "ChatRequestProviderSortConfigEnum": ".chatrequest",
    "ChatRequestProviderSortConfigTypedDict": ".chatrequest",
    "ChatRequestProviderSortConfigUnion": ".chatrequest",
    "ChatRequestProviderSortConfigUnionTypedDict": ".chatrequest",
    "ChatRequestProviderTypedDict": ".chatrequest",
    "ChatRequestServiceTier": ".chatrequest",
    "ChatRequestSortEnum": ".chatrequest",
    "ChatRequestSortUnion": ".chatrequest",
    "ChatRequestSortUnionTypedDict": ".chatrequest",
    "ChatRequestTTL": ".chatrequest",
    "ChatRequestTrace": ".chatrequest",
    "ChatRequestTraceTypedDict": ".chatrequest",
    "ChatRequestType": ".chatrequest",
    "ChatRequestTypedDict": ".chatrequest",
    "Effort": ".chatrequest",
    "Modality": ".chatrequest",
    "Reasoning": ".chatrequest",
    "ReasoningTypedDict": ".chatrequest",
    "ResponseFormat": ".chatrequest",
    "ResponseFormatTypedDict": ".chatrequest",
    "Stop": ".chatrequest",
    "StopTypedDict": ".chatrequest",
    "ChatResult": ".chatresult",
    "ChatResultObject": ".chatresult",
    "ChatResultTypedDict": ".chatresult",
    "ChatStreamChoice": ".chatstreamchoice",
    "ChatStreamChoiceTypedDict": ".chatstreamchoice",
    "ChatStreamChunk": ".chatstreamchunk",
    "ChatStreamChunkObject": ".chatstreamchunk",
    "ChatStreamChunkTypedDict": ".chatstreamchunk",
    "Error": ".chatstreamchunk",
    "ErrorTypedDict": ".chatstreamchunk",
    "ChatStreamDelta": ".chatstreamdelta",
    "ChatStreamDeltaRole": ".chatstreamdelta",
    "ChatStreamDeltaTypedDict": ".chatstreamdelta",
    "ChatStreamOptions": ".chatstreamoptions",
    "ChatStreamOptionsTypedDict": ".chatstreamoptions",
    "ChatStreamToolCall": ".chatstreamtoolcall",
    "ChatStreamToolCallFunction": ".chatstreamtoolcall",
    "ChatStreamToolCallFunctionTypedDict": ".chatstreamtoolcall",
    "ChatStreamToolCallType": ".chatstreamtoolcall",
    "ChatStreamToolCallTypedDict": ".chatstreamtoolcall",
    "ChatSystemMessage": ".chatsystemmessage",
    "ChatSystemMessageContent": ".chatsystemmessage",
    "ChatSystemMessageContentTypedDict": ".chatsystemmessage",
    "ChatSystemMessageRole": ".chatsystemmessage",
    "ChatSystemMessageTypedDict": ".chatsystemmessage",
    "ChatTokenLogprob": ".chattokenlogprob",
    "ChatTokenLogprobTopLogprob": ".chattokenlogprob",
    "ChatTokenLogprobTopLogprobTypedDict": ".chattokenlogprob",
    "ChatTokenLogprobTypedDict": ".chattokenlogprob",
    "ChatTokenLogprobs": ".chattokenlogprobs",
    "ChatTokenLogprobsTypedDict": ".chattokenlogprobs",
    "ChatToolCall": ".chattoolcall",
    "ChatToolCallFunction": ".chattoolcall",
    "ChatToolCallFunctionTypedDict": ".chattoolcall",
    "ChatToolCallType": ".chattoolcall",
    "ChatToolCallTypedDict": ".chattoolcall",
    "ChatToolChoice": ".chattoolchoice",
    "ChatToolChoiceAuto": ".chattoolchoice",
    "ChatToolChoiceNone": ".chattoolchoice",
    "ChatToolChoiceRequired": ".chattoolchoice",
    "ChatToolChoiceTypedDict": ".chattoolchoice",
    "ChatToolMessage": ".chattoolmessage",
    "ChatToolMessageContent": ".chattoolmessage",
    "ChatToolMessageContentTypedDict": ".chattoolmessage",
    "ChatToolMessageRole": ".chattoolmessage",
    "ChatToolMessageTypedDict": ".chattoolmessage",
    "ChatUsage": ".chatusage",
    "ChatUsageTypedDict": ".chatusage",
    "CompletionTokensDetails": ".chatusage",
    "CompletionTokensDetailsTypedDict": ".chatusage",
    "PromptTokensDetails": ".chatusage",
    "PromptTokensDetailsTypedDict": ".chatusage",
    "ChatUserMessage": ".chatusermessage",
    "ChatUserMessageContent": ".chatusermessage",
    "ChatUserMessageContentTypedDict": ".chatusermessage",
    "ChatUserMessageRole": ".chatusermessage",
    "ChatUserMessageTypedDict": ".chatusermessage",
    "ChatWebSearchServerTool": ".chatwebsearchservertool",
    "ChatWebSearchServerToolEngine": ".chatwebsearchservertool",
    "ChatWebSearchServerToolParameters": ".chatwebsearchservertool",
    "ChatWebSearchServerToolParametersType": ".chatwebsearchservertool",
    "ChatWebSearchServerToolParametersTypedDict": ".chatwebsearchservertool",
    "ChatWebSearchServerToolSearchContextSize": ".chatwebsearchservertool",
    "ChatWebSearchServerToolTypeOpenrouterWebSearch": ".chatwebsearchservertool",
    "ChatWebSearchServerToolTypedDict": ".chatwebsearchservertool",
    "ChatWebSearchServerToolUserLocation": ".chatwebsearchservertool",
    "ChatWebSearchServerToolUserLocationTypedDict": ".chatwebsearchservertool",
    "ChatWebSearchShorthand": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandEngine": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParameters": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParametersEngine": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParametersSearchContextSize": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParametersType": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParametersTypedDict": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParametersUserLocation": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandParametersUserLocationTypedDict": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandSearchContextSize": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandType": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandTypeApproximate": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandTypedDict": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandUserLocation": ".chatwebsearchshorthand",
    "ChatWebSearchShorthandUserLocationTypedDict": ".chatwebsearchshorthand",
    "CodeInterpreterServerTool": ".codeinterpreterservertool",
    "CodeInterpreterServerToolTypedDict": ".codeinterpreterservertool",
    "Container": ".codeinterpreterservertool",
    "ContainerAuto": ".codeinterpreterservertool",
    "ContainerAutoTypedDict": ".codeinterpreterservertool",
    "ContainerType": ".codeinterpreterservertool",
    "ContainerTypedDict": ".codeinterpreterservertool",
    "MemoryLimit": ".codeinterpreterservertool",
    "TypeCodeInterpreter": ".codeinterpreterservertool",
    "CodexLocalShellTool": ".codexlocalshelltool",
    "CodexLocalShellToolType": ".codexlocalshelltool",
    "CodexLocalShellToolTypedDict": ".codexlocalshelltool",
    "CompoundFilter": ".compoundfilter",
    "CompoundFilterType": ".compoundfilter",
    "CompoundFilterTypedDict": ".compoundfilter",
    "ComputerUseServerTool": ".computeruseservertool",
    "ComputerUseServerToolType": ".computeruseservertool",
    "ComputerUseServerToolTypedDict": ".computeruseservertool",
    "Environment": ".computeruseservertool",
    "ConflictResponseErrorData": ".conflictresponseerrordata",
    "ConflictResponseErrorDataTypedDict": ".conflictresponseerrordata",
    "ContentPartAddedEvent": ".contentpartaddedevent",
    "ContentPartAddedEventPart": ".contentpartaddedevent",
    "ContentPartAddedEventPartTypedDict": ".contentpartaddedevent",
    "ContentPartAddedEventType": ".contentpartaddedevent",
    "ContentPartAddedEventTypedDict": ".contentpartaddedevent",
    "ContentPartDoneEvent": ".contentpartdoneevent",
    "ContentPartDoneEventPart": ".contentpartdoneevent",
    "ContentPartDoneEventPartTypedDict": ".contentpartdoneevent",
    "ContentPartDoneEventType": ".contentpartdoneevent",
    "ContentPartDoneEventTypedDict": ".contentpartdoneevent",
    "ContextCompressionEngine": ".contextcompressionengine",
    "ChainID": ".createchargerequest",
    "CreateChargeRequest": ".createchargerequest",
    "CreateChargeRequestTypedDict": ".createchargerequest",
    "CustomTool": ".customtool",
    "CustomToolTypedDict": ".customtool",
    "Format": ".customtool",
    "FormatGrammar": ".customtool",
    "FormatGrammarTypedDict": ".customtool",
    "FormatText": ".customtool",
    "FormatTextTypedDict": ".customtool",
    "FormatTypeGrammar": ".customtool",
    "FormatTypeText": ".customtool",
    "FormatTypedDict": ".customtool",
    "Syntax": ".customtool",
    "TypeCustom": ".customtool",
    "DataCollection": ".datacollection",
    "DatetimeServerTool": ".datetimeservertool",
    "DatetimeServerToolParameters": ".datetimeservertool",
    "DatetimeServerToolParametersTypedDict": ".datetimeservertool",
    "DatetimeServerToolType": ".datetimeservertool",
    "DatetimeServerToolTypedDict": ".datetimeservertool",
    "DefaultParameters": ".defaultparameters",
    "DefaultParametersTypedDict": ".defaultparameters",
    "EasyInputMessage": ".easyinputmessage",
    "EasyInputMessageContentInputImage": ".easyinputmessage",
    "EasyInputMessageContentInputImageTypedDict": ".easyinputmessage",
    "EasyInputMessageContentType": ".easyinputmessage",
    "EasyInputMessageContentUnion1": ".easyinputmessage",
    "EasyInputMessageContentUnion1TypedDict": ".easyinputmessage",
    "EasyInputMessageContentUnion2": ".easyinputmessage",
    "EasyInputMessageContentUnion2TypedDict": ".easyinputmessage",
    "EasyInputMessageDetail": ".easyinputmessage",
    "EasyInputMessagePhaseCommentary": ".easyinputmessage",
    "EasyInputMessagePhaseFinalAnswer": ".easyinputmessage",
    "EasyInputMessagePhaseUnion": ".easyinputmessage",
    "EasyInputMessagePhaseUnionTypedDict": ".easyinputmessage",
    "EasyInputMessageRoleAssistant": ".easyinputmessage",
    "EasyInputMessageRoleDeveloper": ".easyinputmessage",
    "EasyInputMessageRoleSystem": ".easyinputmessage",
    "EasyInputMessageRoleUnion": ".easyinputmessage",
    "EasyInputMessageRoleUnionTypedDict": ".easyinputmessage",
    "EasyInputMessageRoleUser": ".easyinputmessage",
    "EasyInputMessageTypeMessage": ".easyinputmessage",
    "EasyInputMessageTypedDict": ".easyinputmessage",
    "EdgeNetworkTimeoutResponseErrorData": ".edgenetworktimeoutresponseerrordata",
    "EdgeNetworkTimeoutResponseErrorDataTypedDict": ".edgenetworktimeoutresponseerrordata",
    "EndpointStatus": ".endpointstatus",
    "ErrorEvent": ".errorevent",
    "ErrorEventType": ".errorevent",
    "ErrorEventTypedDict": ".errorevent",
    "FileCitation": ".filecitation",
    "FileCitationType": ".filecitation",
    "FileCitationTypedDict": ".filecitation",
    "FilePath": ".filepath",
    "FilePathType": ".filepath",
    "FilePathTypedDict": ".filepath",
    "FileSearchServerTool": ".filesearchservertool",
    "FileSearchServerToolFilters": ".filesearchservertool",
    "FileSearchServerToolFiltersTypedDict": ".filesearchservertool",
    "FileSearchServerToolTypedDict": ".filesearchservertool",
    "Filters": ".filesearchservertool",
    "FiltersType": ".filesearchservertool",
    "FiltersTypedDict": ".filesearchservertool",
    "Ranker": ".filesearchservertool",
    "RankingOptions": ".filesearchservertool",
    "RankingOptionsTypedDict": ".filesearchservertool",
    "TypeFileSearch": ".filesearchservertool",
    "Value1": ".filesearchservertool",
    "Value1TypedDict": ".filesearchservertool",
    "Value2": ".filesearchservertool",
    "Value2TypedDict": ".filesearchservertool",
    "ForbiddenResponseErrorData": ".forbiddenresponseerrordata",
    "ForbiddenResponseErrorDataTypedDict": ".forbiddenresponseerrordata",
    "FormatJSONObjectConfig": ".formatjsonobjectconfig",
    "FormatJSONObjectConfigType": ".formatjsonobjectconfig",
    "FormatJSONObjectConfigTypedDict": ".formatjsonobjectconfig",
    "FormatJSONSchemaConfig": ".formatjsonschemaconfig",
    "FormatJSONSchemaConfigType": ".formatjsonschemaconfig",
    "FormatJSONSchemaConfigTypedDict": ".formatjsonschemaconfig",
    "Formats": ".formats",
    "FormatsTypedDict": ".formats",
    "FormatTextConfig": ".formattextconfig",
    "FormatTextConfigType": ".formattextconfig",
    "FormatTextConfigTypedDict": ".formattextconfig",
    "FunctionCallArgsDeltaEvent": ".functioncallargsdeltaevent",
    "FunctionCallArgsDeltaEventType": ".functioncallargsdeltaevent",
    "FunctionCallArgsDeltaEventTypedDict": ".functioncallargsdeltaevent",
    "FunctionCallArgsDoneEvent": ".functioncallargsdoneevent",
    "FunctionCallArgsDoneEventType": ".functioncallargsdoneevent",
    "FunctionCallArgsDoneEventTypedDict": ".functioncallargsdoneevent",
    "FunctionCallItem": ".functioncallitem",
    "FunctionCallItemType": ".functioncallitem",
    "FunctionCallItemTypedDict": ".functioncallitem",
    "FunctionCallOutputItem": ".functioncalloutputitem",
    "FunctionCallOutputItemDetail": ".functioncalloutputitem",
    "FunctionCallOutputItemOutputUnion1": ".functioncalloutputitem",
    "FunctionCallOutputItemOutputUnion1TypedDict": ".functioncalloutputitem",
    "FunctionCallOutputItemOutputUnion2": ".functioncalloutputitem",
    "FunctionCallOutputItemOutputUnion2TypedDict": ".functioncalloutputitem",
    "FunctionCallOutputItemTypeFunctionCallOutput": ".functioncalloutputitem",
    "FunctionCallOutputItemTypedDict": ".functioncalloutputitem",
    "OutputInputImage": ".functioncalloutputitem",
    "OutputInputImageTypedDict": ".functioncalloutputitem",
    "OutputType": ".functioncalloutputitem",
    "ImageGenCallCompletedEvent": ".imagegencallcompletedevent",
    "ImageGenCallCompletedEventType": ".imagegencallcompletedevent",
    "ImageGenCallCompletedEventTypedDict": ".imagegencallcompletedevent",
    "ImageGenCallGeneratingEvent": ".imagegencallgeneratingevent",
    "ImageGenCallGeneratingEventType": ".imagegencallgeneratingevent",
    "ImageGenCallGeneratingEventTypedDict": ".imagegencallgeneratingevent",
    "ImageGenCallInProgressEvent": ".imagegencallinprogressevent",
    "ImageGenCallInProgressEventType": ".imagegencallinprogressevent",
    "ImageGenCallInProgressEventTypedDict": ".imagegencallinprogressevent",
    "ImageGenCallPartialImageEvent": ".imagegencallpartialimageevent",
    "ImageGenCallPartialImageEventType": ".imagegencallpartialimageevent",
    "ImageGenCallPartialImageEventTypedDict": ".imagegencallpartialimageevent",
    "Background": ".imagegenerationservertool",
    "ImageGenerationServerTool": ".imagegenerationservertool",
    "ImageGenerationServerToolType": ".imagegenerationservertool",
    "ImageGenerationServerToolTypedDict": ".imagegenerationservertool",
    "InputFidelity": ".imagegenerationservertool",
    "InputImageMask": ".imagegenerationservertool",
    "InputImageMaskTypedDict": ".imagegenerationservertool",
    "ModelEnum": ".imagegenerationservertool",
    "Moderation": ".imagegenerationservertool",
    "OutputFormat": ".imagegenerationservertool",
    "Quality": ".imagegenerationservertool",
    "Size": ".imagegenerationservertool",
    "ImageGenerationStatus": ".imagegenerationstatus",
    "IncompleteDetails": ".incompletedetails",
    "IncompleteDetailsTypedDict": ".incompletedetails",
    "Reason": ".incompletedetails",
    "InputAudio": ".inputaudio",
    "InputAudioFormat": ".inputaudio",
    "InputAudioInputAudio": ".inputaudio",
    "InputAudioInputAudioTypedDict": ".inputaudio",
    "InputAudioType": ".inputaudio",
    "InputAudioTypedDict": ".inputaudio",
    "InputFile": ".inputfile",
    "InputFileType": ".inputfile",
    "InputFileTypedDict": ".inputfile",
    "InputImage": ".inputimage",
    "InputImageDetail": ".inputimage",
    "InputImageType": ".inputimage",
    "InputImageTypedDict": ".inputimage",
    "InputMessageItem": ".inputmessageitem",
    "InputMessageItemContentInputImage": ".inputmessageitem",
    "InputMessageItemContentInputImageTypedDict": ".inputmessageitem",
    "InputMessageItemContentType": ".inputmessageitem",
    "InputMessageItemContentUnion": ".inputmessageitem",
    "InputMessageItemContentUnionTypedDict": ".inputmessageitem",
    "InputMessageItemDetail": ".inputmessageitem",
    "InputMessageItemRoleDeveloper": ".inputmessageitem",
    "InputMessageItemRoleSystem": ".inputmessageitem",
    "InputMessageItemRoleUnion": ".inputmessageitem",
    "InputMessageItemRoleUnionTypedDict": ".inputmessageitem",
    "InputMessageItemRoleUser": ".inputmessageitem",
    "InputMessageItemTypeMessage": ".inputmessageitem",
    "InputMessageItemTypedDict": ".inputmessageitem",
    "InputModality": ".inputmodality",
    "InputsContent1": ".inputs_union",
    "InputsContent1TypedDict": ".inputs_union",
    "InputsContent2": ".inputs_union",
    "InputsContent2TypedDict": ".inputs_union",
    "InputsFormat": ".inputs_union",
    "InputsMessage": ".inputs_union",
    "InputsMessageTypedDict": ".inputs_union",
    "InputsPhaseCommentary": ".inputs_union",
    "InputsPhaseFinalAnswer": ".inputs_union",
    "InputsPhaseUnion": ".inputs_union",
    "InputsPhaseUnionTypedDict": ".inputs_union",
    "InputsReasoning": ".inputs_union",
    "InputsReasoningTypedDict": ".inputs_union",
    "InputsRole": ".inputs_union",
    "InputsStatusCompleted1": ".inputs_union",
    "InputsStatusCompleted2": ".inputs_union",
    "InputsStatusInProgress1": ".inputs_union",
    "InputsStatusInProgress2": ".inputs_union",
    "InputsStatusIncomplete1": ".inputs_union",
    "InputsStatusIncomplete2": ".inputs_union",
    "InputsStatusUnion1": ".inputs_union",
    "InputsStatusUnion1TypedDict": ".inputs_union",
    "InputsStatusUnion2": ".inputs_union",
    "InputsStatusUnion2TypedDict": ".inputs_union",
    "InputsTypeMessage": ".inputs_union",
    "InputsTypeReasoning": ".inputs_union",
    "InputsUnion": ".inputs_union",
    "InputsUnion1": ".inputs_union",
    "InputsUnion1TypedDict": ".inputs_union",
    "InputsUnionTypedDict": ".inputs_union",
    "InputText": ".inputtext",
    "InputTextType": ".inputtext",
    "InputTextTypedDict": ".inputtext",
    "InputVideo": ".inputvideo",
    "InputVideoType": ".inputvideo",
    "InputVideoTypedDict": ".inputvideo",
    "InstructType": ".instructtype",
    "InternalServerResponseErrorData": ".internalserverresponseerrordata",
    "InternalServerResponseErrorDataTypedDict": ".internalserverresponseerrordata",
    "LegacyChatContentVideo": ".legacy_chatcontentvideo",
    "LegacyChatContentVideoType": ".legacy_chatcontentvideo",
    "LegacyChatContentVideoTypedDict": ".legacy_chatcontentvideo",
    "LegacyWebSearchServerTool": ".legacy_websearchservertool",
    "LegacyWebSearchServerToolEngine": ".legacy_websearchservertool",
    "LegacyWebSearchServerToolFilters": ".legacy_websearchservertool",
    "LegacyWebSearchServerToolFiltersTypedDict": ".legacy_websearchservertool",
    "LegacyWebSearchServerToolType": ".legacy_websearchservertool",
    "LegacyWebSearchServerToolTypedDict": ".legacy_websearchservertool",
    "Architecture": ".listendpointsresponse",
    "ArchitectureTypedDict": ".listendpointsresponse",
    "ListEndpointsResponse": ".listendpointsresponse",
    "ListEndpointsResponseTypedDict": ".listendpointsresponse",
    "Tokenizer": ".listendpointsresponse",
    "AllowedTools": ".mcpservertool",
    "AllowedToolsTypedDict": ".mcpservertool",
    "Always": ".mcpservertool",
    "AlwaysTypedDict": ".mcpservertool",
    "ConnectorID": ".mcpservertool",
    "McpServerTool": ".mcpservertool",
    "McpServerToolType": ".mcpservertool",
    "McpServerToolTypedDict": ".mcpservertool",
    "Never": ".mcpservertool",
    "NeverTypedDict": ".mcpservertool",
    "RequireApproval": ".mcpservertool",
    "RequireApprovalAlways": ".mcpservertool",
    "RequireApprovalNever": ".mcpservertool",
    "RequireApprovalTypedDict": ".mcpservertool",
    "Model": ".model",
    "ModelTypedDict": ".model",
    "ModelArchitecture": ".modelarchitecture",
    "ModelArchitectureInstructType": ".modelarchitecture",
    "ModelArchitectureTypedDict": ".modelarchitecture",
    "ModelGroup": ".modelgroup",
    "Data": ".modelscountresponse",
    "DataTypedDict": ".modelscountresponse",
    "ModelsCountResponse": ".modelscountresponse",
    "ModelsCountResponseTypedDict": ".modelscountresponse",
    "ModelsListResponse": ".modelslistresponse",
    "ModelsListResponseTypedDict": ".modelslistresponse",
    "NotFoundResponseErrorData": ".notfoundresponseerrordata",
    "NotFoundResponseErrorDataTypedDict": ".notfoundresponseerrordata",
    "OpenAIResponsesAnnotation": ".openairesponsesannotation",
    "OpenAIResponsesAnnotationTypedDict": ".openairesponsesannotation",
    "OpenAIResponsesRefusalContent": ".openairesponsesrefusalcontent",
    "OpenAIResponsesRefusalContentType": ".openairesponsesrefusalcontent",
    "OpenAIResponsesRefusalContentTypedDict": ".openairesponsesrefusalcontent",
    "OpenAIResponsesResponseStatus": ".openairesponsesresponsestatus",
    "OpenAIResponsesToolChoice": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceAuto": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceFunction": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceFunctionTypedDict": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceNone": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceRequired": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypeFunction": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview20250311": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypedDict": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceUnion": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceUnionTypedDict": ".openairesponsestoolchoice_union",
    "Type": ".openairesponsestoolchoice_union",
    "TypeTypedDict": ".openairesponsestoolchoice_union",
    "OpenAIResponsesTruncation": ".openairesponsestruncation",
    "OpenResponsesResult": ".openresponsesresult",
    "OpenResponsesResultObject": ".openresponsesresult",
    "OpenResponsesResultToolFunction": ".openresponsesresult",
    "OpenResponsesResultToolFunctionTypedDict": ".openresponsesresult",
    "OpenResponsesResultToolUnion": ".openresponsesresult",
    "OpenResponsesResultToolUnionTypedDict": ".openresponsesresult",
    "OpenResponsesResultType": ".openresponsesresult",
    "OpenResponsesResultTypedDict": ".openresponsesresult",
    "OutputDatetimeItem": ".outputdatetimeitem",
    "OutputDatetimeItemStatus": ".outputdatetimeitem",
    "OutputDatetimeItemType": ".outputdatetimeitem",
    "OutputDatetimeItemTypedDict": ".outputdatetimeitem",
    "OutputFileSearchCallItem": ".outputfilesearchcallitem",
    "OutputFileSearchCallItemType": ".outputfilesearchcallitem",
    "OutputFileSearchCallItemTypedDict": ".outputfilesearchcallitem",
    "OutputFunctionCallItem": ".outputfunctioncallitem",
    "OutputFunctionCallItemStatusCompleted": ".outputfunctioncallitem",
    "OutputFunctionCallItemStatusInProgress": ".outputfunctioncallitem",
    "OutputFunctionCallItemStatusIncomplete": ".outputfunctioncallitem",
    "OutputFunctionCallItemStatusUnion": ".outputfunctioncallitem",
    "OutputFunctionCallItemStatusUnionTypedDict": ".outputfunctioncallitem",
    "OutputFunctionCallItemType": ".outputfunctioncallitem",
    "OutputFunctionCallItemTypedDict": ".outputfunctioncallitem",
    "OutputImageGenerationCallItem": ".outputimagegenerationcallitem",
    "OutputImageGenerationCallItemType": ".outputimagegenerationcallitem",
    "OutputImageGenerationCallItemTypedDict": ".outputimagegenerationcallitem",
    "OutputItemImageGenerationCall": ".outputitemimagegenerationcall",
    "OutputItemImageGenerationCallType": ".outputitemimagegenerationcall",
    "OutputItemImageGenerationCallTypedDict": ".outputitemimagegenerationcall",
    "OutputItems": ".outputitems",
    "OutputItemsTypedDict": ".outputitems",
    "OutputMessage": ".outputmessage",
    "OutputMessageContent": ".outputmessage",
    "OutputMessageContentTypedDict": ".outputmessage",
    "OutputMessagePhaseCommentary": ".outputmessage",
    "OutputMessagePhaseFinalAnswer": ".outputmessage",
    "OutputMessagePhaseUnion": ".outputmessage",
    "OutputMessagePhaseUnionTypedDict": ".outputmessage",
    "OutputMessageRole": ".outputmessage",
    "OutputMessageStatusCompleted": ".outputmessage",
    "OutputMessageStatusInProgress": ".outputmessage",
    "OutputMessageStatusIncomplete": ".outputmessage",
    "OutputMessageStatusUnion": ".outputmessage",
    "OutputMessageStatusUnionTypedDict": ".outputmessage",
    "OutputMessageType": ".outputmessage",
    "OutputMessageTypedDict": ".outputmessage",
    "OutputMessageItem": ".outputmessageitem",
    "OutputMessageItemContent": ".outputmessageitem",
    "OutputMessageItemContentTypedDict": ".outputmessageitem",
    "OutputMessageItemPhaseCommentary": ".outputmessageitem",
    "OutputMessageItemPhaseFinalAnswer": ".outputmessageitem",
    "OutputMessageItemPhaseUnion": ".outputmessageitem",
    "OutputMessageItemPhaseUnionTypedDict": ".outputmessageitem",
    "OutputMessageItemRole": ".outputmessageitem",
    "OutputMessageItemStatusCompleted": ".outputmessageitem",
    "OutputMessageItemStatusInProgress": ".outputmessageitem",
    "OutputMessageItemStatusIncomplete": ".outputmessageitem",
    "OutputMessageItemStatusUnion": ".outputmessageitem",
    "OutputMessageItemStatusUnionTypedDict": ".outputmessageitem",
    "OutputMessageItemType": ".outputmessageitem",
    "OutputMessageItemTypedDict": ".outputmessageitem",
    "OutputModality": ".outputmodality",
    "OutputModalityEnum": ".outputmodalityenum",
    "OutputReasoningItem": ".outputreasoningitem",
    "OutputReasoningItemFormat": ".outputreasoningitem",
    "OutputReasoningItemStatusCompleted": ".outputreasoningitem",
    "OutputReasoningItemStatusInProgress": ".outputreasoningitem",
    "OutputReasoningItemStatusIncomplete": ".outputreasoningitem",
    "OutputReasoningItemStatusUnion": ".outputreasoningitem",
    "OutputReasoningItemStatusUnionTypedDict": ".outputreasoningitem",
    "OutputReasoningItemType": ".outputreasoningitem",
    "OutputReasoningItemTypedDict": ".outputreasoningitem",
    "OutputServerToolItem": ".outputservertoolitem",
    "OutputServerToolItemStatus": ".outputservertoolitem",
    "OutputServerToolItemTypedDict": ".outputservertoolitem",
    "Action": ".outputwebsearchcallitem",
    "ActionFindInPage": ".outputwebsearchcallitem",
    "ActionFindInPageTypedDict": ".outputwebsearchcallitem",
    "ActionOpenPage": ".outputwebsearchcallitem",
    "ActionOpenPageTypedDict": ".outputwebsearchcallitem",
    "ActionSearch": ".outputwebsearchcallitem",
    "ActionSearchTypedDict": ".outputwebsearchcallitem",
    "ActionTypedDict": ".outputwebsearchcallitem",
    "OutputWebSearchCallItem": ".outputwebsearchcallitem",
    "OutputWebSearchCallItemTypedDict": ".outputwebsearchcallitem",
    "Source": ".outputwebsearchcallitem",
    "SourceTypedDict": ".outputwebsearchcallitem",
    "TypeFindInPage": ".outputwebsearchcallitem",
    "TypeOpenPage": ".outputwebsearchcallitem",
    "TypeSearch": ".outputwebsearchcallitem",
    "TypeURL": ".outputwebsearchcallitem",
    "TypeWebSearchCall": ".outputwebsearchcallitem",
    "Parameter": ".parameter",
    "PayloadTooLargeResponseErrorData": ".payloadtoolargeresponseerrordata",
    "PayloadTooLargeResponseErrorDataTypedDict": ".payloadtoolargeresponseerrordata",
    "PaymentRequiredResponseErrorData": ".paymentrequiredresponseerrordata",
    "PaymentRequiredResponseErrorDataTypedDict": ".paymentrequiredresponseerrordata",
    "PDFParserEngine": ".pdfparserengine",
    "PDFParserEngineEnum": ".pdfparserengine",
    "PDFParserEnginePDFText": ".pdfparserengine",
    "PDFParserEngineTypedDict": ".pdfparserengine",
    "PDFParserOptions": ".pdfparseroptions",
    "PDFParserOptionsTypedDict": ".pdfparseroptions",
    "PercentileLatencyCutoffs": ".percentilelatencycutoffs",
    "PercentileLatencyCutoffsTypedDict": ".percentilelatencycutoffs",
    "PercentileStats": ".percentilestats",
    "PercentileStatsTypedDict": ".percentilestats",
    "PercentileThroughputCutoffs": ".percentilethroughputcutoffs",
    "PercentileThroughputCutoffsTypedDict": ".percentilethroughputcutoffs",
    "PerRequestLimits": ".perrequestlimits",
    "PerRequestLimitsTypedDict": ".perrequestlimits",
    "PreferredMaxLatency": ".preferredmaxlatency",
    "PreferredMaxLatencyTypedDict": ".preferredmaxlatency",
    "PreferredMinThroughput": ".preferredminthroughput",
    "PreferredMinThroughputTypedDict": ".preferredminthroughput",
    "Preview20250311WebSearchServerTool": ".preview_20250311_websearchservertool",
    "Preview20250311WebSearchServerToolEngine": ".preview_20250311_websearchservertool",
    "Preview20250311WebSearchServerToolFilters": ".preview_20250311_websearchservertool",
    "Preview20250311WebSearchServerToolFiltersTypedDict": ".preview_20250311_websearchservertool",
    "Preview20250311WebSearchServerToolType": ".preview_20250311_websearchservertool",
    "Preview20250311WebSearchServerToolTypedDict": ".preview_20250311_websearchservertool",
    "PreviewWebSearchServerTool": ".preview_websearchservertool",
    "PreviewWebSearchServerToolEngine": ".preview_websearchservertool",
    "PreviewWebSearchServerToolFilters": ".preview_websearchservertool",
    "PreviewWebSearchServerToolFiltersTypedDict": ".preview_websearchservertool",
    "PreviewWebSearchServerToolType": ".preview_websearchservertool",
    "PreviewWebSearchServerToolTypedDict": ".preview_websearchservertool",
    "PreviewWebSearchUserLocation": ".preview_websearchuserlocation",
    "PreviewWebSearchUserLocationType": ".preview_websearchuserlocation",
    "PreviewWebSearchUserLocationTypedDict": ".preview_websearchuserlocation",
    "ProviderName": ".providername",
    "ProviderOverloadedResponseErrorData": ".provideroverloadedresponseerrordata",
    "ProviderOverloadedResponseErrorDataTypedDict": ".provideroverloadedresponseerrordata",
    "ProviderPreferences": ".providerpreferences",
    "ProviderPreferencesBy": ".providerpreferences",
    "ProviderPreferencesIgnore": ".providerpreferences",
    "ProviderPreferencesIgnoreTypedDict": ".providerpreferences",
    "ProviderPreferencesMaxPrice": ".providerpreferences",
    "ProviderPreferencesMaxPriceTypedDict": ".providerpreferences",
    "ProviderPreferencesOnly": ".providerpreferences",
    "ProviderPreferencesOnlyTypedDict": ".providerpreferences",
    "ProviderPreferencesOrder": ".providerpreferences",
    "ProviderPreferencesOrderTypedDict": ".providerpreferences",
    "ProviderPreferencesPartition": ".providerpreferences",
    "ProviderPreferencesProviderSort": ".providerpreferences",
    "ProviderPreferencesProviderSortConfig": ".providerpreferences",
    "ProviderPreferencesProviderSortConfigEnum": ".providerpreferences",
    "ProviderPreferencesProviderSortConfigTypedDict": ".providerpreferences",
    "ProviderPreferencesProviderSortConfigUnion": ".providerpreferences",
    "ProviderPreferencesProviderSortConfigUnionTypedDict": ".providerpreferences",
    "ProviderPreferencesSortEnum": ".providerpreferences",
    "ProviderPreferencesSortUnion": ".providerpreferences",
    "ProviderPreferencesSortUnionTypedDict": ".providerpreferences",
    "ProviderPreferencesTypedDict": ".providerpreferences",
    "ProviderSort": ".providersort",
    "By": ".providersortconfig",
    "Partition": ".providersortconfig",
    "ProviderSortConfig": ".providersortconfig",
    "ProviderSortConfigTypedDict": ".providersortconfig",
    "Pricing": ".publicendpoint",
    "PricingTypedDict": ".publicendpoint",
    "PublicEndpoint": ".publicendpoint",
    "PublicEndpointQuantization": ".publicendpoint",
    "PublicEndpointTypedDict": ".publicendpoint",
    "PublicPricing": ".publicpricing",
    "PublicPricingTypedDict": ".publicpricing",
    "Quantization": ".quantization",
    "ReasoningConfig": ".reasoningconfig",
    "ReasoningConfigTypedDict": ".reasoningconfig",
    "ReasoningDeltaEvent": ".reasoningdeltaevent",
    "ReasoningDeltaEventType": ".reasoningdeltaevent",
    "ReasoningDeltaEventTypedDict": ".reasoningdeltaevent",
    "ReasoningDetailEncrypted": ".reasoningdetailencrypted",
    "ReasoningDetailEncryptedFormat": ".reasoningdetailencrypted",
    "ReasoningDetailEncryptedType": ".reasoningdetailencrypted",
    "ReasoningDetailEncryptedTypedDict": ".reasoningdetailencrypted",
    "ReasoningDetailSummary": ".reasoningdetailsummary",
    "ReasoningDetailSummaryFormat": ".reasoningdetailsummary",
    "ReasoningDetailSummaryType": ".reasoningdetailsummary",
    "ReasoningDetailSummaryTypedDict": ".reasoningdetailsummary",
    "ReasoningDetailText": ".reasoningdetailtext",
    "ReasoningDetailTextFormat": ".reasoningdetailtext",
    "ReasoningDetailTextType": ".reasoningdetailtext",
    "ReasoningDetailTextTypedDict": ".reasoningdetailtext",
    "ReasoningDetailUnion": ".reasoningdetailunion",
    "ReasoningDetailUnionTypedDict": ".reasoningdetailunion",
    "ReasoningDoneEvent": ".reasoningdoneevent",
    "ReasoningDoneEventType": ".reasoningdoneevent",
    "ReasoningDoneEventTypedDict": ".reasoningdoneevent",
    "ReasoningEffortEnum": ".reasoningeffortenum",
    "ReasoningItem": ".reasoningitem",
    "ReasoningItemFormat": ".reasoningitem",
    "ReasoningItemStatusCompleted": ".reasoningitem",
    "ReasoningItemStatusInProgress": ".reasoningitem",
    "ReasoningItemStatusIncomplete": ".reasoningitem",
    "ReasoningItemStatusUnion": ".reasoningitem",
    "ReasoningItemStatusUnionTypedDict": ".reasoningitem",
    "ReasoningItemType": ".reasoningitem",
    "ReasoningItemTypedDict": ".reasoningitem",
    "ReasoningSummaryPartAddedEvent": ".reasoningsummarypartaddedevent",
    "ReasoningSummaryPartAddedEventType": ".reasoningsummarypartaddedevent",
    "ReasoningSummaryPartAddedEventTypedDict": ".reasoningsummarypartaddedevent",
    "ReasoningSummaryPartDoneEvent": ".reasoningsummarypartdoneevent",
    "ReasoningSummaryPartDoneEventType": ".reasoningsummarypartdoneevent",
    "ReasoningSummaryPartDoneEventTypedDict": ".reasoningsummarypartdoneevent",
    "ReasoningSummaryText": ".reasoningsummarytext",
    "ReasoningSummaryTextType": ".reasoningsummarytext",
    "ReasoningSummaryTextTypedDict": ".reasoningsummarytext",
    "ReasoningSummaryTextDeltaEvent": ".reasoningsummarytextdeltaevent",
    "ReasoningSummaryTextDeltaEventType": ".reasoningsummarytextdeltaevent",
    "ReasoningSummaryTextDeltaEventTypedDict": ".reasoningsummarytextdeltaevent",
    "ReasoningSummaryTextDoneEvent": ".reasoningsummarytextdoneevent",
    "ReasoningSummaryTextDoneEventType": ".reasoningsummarytextdoneevent",
    "ReasoningSummaryTextDoneEventTypedDict": ".reasoningsummarytextdoneevent",
    "ReasoningSummaryVerbosityEnum": ".reasoningsummaryverbosityenum",
    "ReasoningTextContent": ".reasoningtextcontent",
    "ReasoningTextContentType": ".reasoningtextcontent",
    "ReasoningTextContentTypedDict": ".reasoningtextcontent",
    "RefusalDeltaEvent": ".refusaldeltaevent",
    "RefusalDeltaEventType": ".refusaldeltaevent",
    "RefusalDeltaEventTypedDict": ".refusaldeltaevent",
    "RefusalDoneEvent": ".refusaldoneevent",
    "RefusalDoneEventType": ".refusaldoneevent",
    "RefusalDoneEventTypedDict": ".refusaldoneevent",
    "RequestTimeoutResponseErrorData": ".requesttimeoutresponseerrordata",
    "RequestTimeoutResponseErrorDataTypedDict": ".requesttimeoutresponseerrordata",
    "ResponseIncludesEnum": ".responseincludesenum",
    "ResponseOutputText": ".responseoutputtext",
    "ResponseOutputTextLogprob": ".responseoutputtext",
    "ResponseOutputTextLogprobTypedDict": ".responseoutputtext",
    "ResponseOutputTextTopLogprob": ".responseoutputtext",
    "ResponseOutputTextTopLogprobTypedDict": ".responseoutputtext",
    "ResponseOutputTextType": ".responseoutputtext",
    "ResponseOutputTextTypedDict": ".responseoutputtext",
    "Code": ".responseserrorfield",
    "ResponsesErrorField": ".responseserrorfield",
    "ResponsesErrorFieldTypedDict": ".responseserrorfield",
    "ResponsesRequest": ".responsesrequest",
    "ResponsesRequestIDAutoRouter": ".responsesrequest",
    "ResponsesRequestIDContextCompression": ".responsesrequest",
    "ResponsesRequestIDFileParser": ".responsesrequest",
    "ResponsesRequestIDModeration": ".responsesrequest",
    "ResponsesRequestIDResponseHealing": ".responsesrequest",
    "ResponsesRequestIDWeb": ".responsesrequest",
    "ResponsesRequestIgnore": ".responsesrequest",
    "ResponsesRequestIgnoreTypedDict": ".responsesrequest",
    "ResponsesRequestImageConfig": ".responsesrequest",
    "ResponsesRequestImageConfigTypedDict": ".responsesrequest",
    "ResponsesRequestMaxPrice": ".responsesrequest",
    "ResponsesRequestMaxPriceTypedDict": ".responsesrequest",
    "ResponsesRequestOnly": ".responsesrequest",
    "ResponsesRequestOnlyTypedDict": ".responsesrequest",
    "ResponsesRequestOrder": ".responsesrequest",
    "ResponsesRequestOrderTypedDict": ".responsesrequest",
    "ResponsesRequestPluginAutoRouter": ".responsesrequest",
    "ResponsesRequestPluginAutoRouterTypedDict": ".responsesrequest",
    "ResponsesRequestPluginContextCompression": ".responsesrequest",
    "ResponsesRequestPluginContextCompressionTypedDict": ".responsesrequest",
    "ResponsesRequestPluginFileParser": ".responsesrequest",
    "ResponsesRequestPluginFileParserTypedDict": ".responsesrequest",
    "ResponsesRequestPluginModeration": ".responsesrequest",
    "ResponsesRequestPluginModerationTypedDict": ".responsesrequest",
    "ResponsesRequestPluginResponseHealing": ".responsesrequest",
    "ResponsesRequestPluginResponseHealingTypedDict": ".responsesrequest",
    "ResponsesRequestPluginUnion": ".responsesrequest",
    "ResponsesRequestPluginUnionTypedDict": ".responsesrequest",
    "ResponsesRequestPluginWeb": ".responsesrequest",
    "ResponsesRequestPluginWebTypedDict": ".responsesrequest",
    "ResponsesRequestProvider": ".responsesrequest",
    "ResponsesRequestProviderTypedDict": ".responsesrequest",
    "ResponsesRequestServiceTier": ".responsesrequest",
    "ResponsesRequestSort": ".responsesrequest",
    "ResponsesRequestSortTypedDict": ".responsesrequest",
    "ResponsesRequestToolFunction": ".responsesrequest",
    "ResponsesRequestToolFunctionTypedDict": ".responsesrequest",
    "ResponsesRequestToolUnion": ".responsesrequest",
    "ResponsesRequestToolUnionTypedDict": ".responsesrequest",
    "ResponsesRequestTrace": ".responsesrequest",
    "ResponsesRequestTraceTypedDict": ".responsesrequest",
    "ResponsesRequestType": ".responsesrequest",
    "ResponsesRequestTypedDict": ".responsesrequest",
    "SearchContextSizeEnum": ".searchcontextsizeenum",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ServiceUnavailableResponseErrorData": ".serviceunavailableresponseerrordata",
    "ServiceUnavailableResponseErrorDataTypedDict": ".serviceunavailableresponseerrordata",
    "ShellServerTool": ".shellservertool",
    "ShellServerToolType": ".shellservertool",
    "ShellServerToolTypedDict": ".shellservertool",
    "StoredPromptTemplate": ".storedprompttemplate",
    "StoredPromptTemplateTypedDict": ".storedprompttemplate",
    "Variables": ".storedprompttemplate",
    "VariablesTypedDict": ".storedprompttemplate",
    "StreamEvents": ".streamevents",
    "StreamEventsResponseCompleted": ".streamevents",
    "StreamEventsResponseCompletedTypedDict": ".streamevents",
    "StreamEventsResponseCreated": ".streamevents",
    "StreamEventsResponseCreatedTypedDict": ".streamevents",
    "StreamEventsResponseFailed": ".streamevents",
    "StreamEventsResponseFailedTypedDict": ".streamevents",
    "StreamEventsResponseInProgress": ".streamevents",
    "StreamEventsResponseInProgressTypedDict": ".streamevents",
    "StreamEventsResponseIncomplete": ".streamevents",
    "StreamEventsResponseIncompleteTypedDict": ".streamevents",
    "StreamEventsResponseOutputItemAdded": ".streamevents",
    "StreamEventsResponseOutputItemAddedTypedDict": ".streamevents",
    "StreamEventsResponseOutputItemDone": ".streamevents",
    "StreamEventsResponseOutputItemDoneTypedDict": ".streamevents",
    "StreamEventsTypedDict": ".streamevents",
    "TypeResponseCompleted": ".streamevents",
    "TypeResponseCreated": ".streamevents",
    "TypeResponseFailed": ".streamevents",
    "TypeResponseInProgress": ".streamevents",
    "TypeResponseIncomplete": ".streamevents",
    "TypeResponseOutputItemAdded": ".streamevents",
    "TypeResponseOutputItemDone": ".streamevents",
    "TextConfig": ".textconfig",
    "TextConfigTypedDict": ".textconfig",
    "TextConfigVerbosity": ".textconfig",
    "TextDeltaEvent": ".textdeltaevent",
    "TextDeltaEventLogprob": ".textdeltaevent",
    "TextDeltaEventLogprobTypedDict": ".textdeltaevent",
    "TextDeltaEventTopLogprob": ".textdeltaevent",
    "TextDeltaEventTopLogprobTypedDict": ".textdeltaevent",
    "TextDeltaEventType": ".textdeltaevent",
    "TextDeltaEventTypedDict": ".textdeltaevent",
    "TextDoneEvent": ".textdoneevent",
    "TextDoneEventLogprob": ".textdoneevent",
    "TextDoneEventLogprobTypedDict": ".textdoneevent",
    "TextDoneEventTopLogprob": ".textdoneevent",
    "TextDoneEventTopLogprobTypedDict": ".textdoneevent",
    "TextDoneEventType": ".textdoneevent",
    "TextDoneEventTypedDict": ".textdoneevent",
    "TextExtendedConfig": ".textextendedconfig",
    "TextExtendedConfigTypedDict": ".textextendedconfig",
    "TextExtendedConfigVerbosity": ".textextendedconfig",
    "ToolCallStatusEnum": ".toolcallstatusenum",
    "TooManyRequestsResponseErrorData": ".toomanyrequestsresponseerrordata",
    "TooManyRequestsResponseErrorDataTypedDict": ".toomanyrequestsresponseerrordata",
    "TopProviderInfo": ".topproviderinfo",
    "TopProviderInfoTypedDict": ".topproviderinfo",
    "TruncationEnum": ".truncationenum",
    "UnauthorizedResponseErrorData": ".unauthorizedresponseerrordata",
    "UnauthorizedResponseErrorDataTypedDict": ".unauthorizedresponseerrordata",
    "UnprocessableEntityResponseErrorData": ".unprocessableentityresponseerrordata",
    "UnprocessableEntityResponseErrorDataTypedDict": ".unprocessableentityresponseerrordata",
    "URLCitation": ".urlcitation",
    "URLCitationType": ".urlcitation",
    "URLCitationTypedDict": ".urlcitation",
    "CostDetails": ".usage",
    "CostDetailsTypedDict": ".usage",
    "InputTokensDetails": ".usage",
    "InputTokensDetailsTypedDict": ".usage",
    "OutputTokensDetails": ".usage",
    "OutputTokensDetailsTypedDict": ".usage",
    "Usage": ".usage",
    "UsageTypedDict": ".usage",
    "WebSearchCallCompletedEvent": ".websearchcallcompletedevent",
    "WebSearchCallCompletedEventType": ".websearchcallcompletedevent",
    "WebSearchCallCompletedEventTypedDict": ".websearchcallcompletedevent",
    "WebSearchCallInProgressEvent": ".websearchcallinprogressevent",
    "WebSearchCallInProgressEventType": ".websearchcallinprogressevent",
    "WebSearchCallInProgressEventTypedDict": ".websearchcallinprogressevent",
    "WebSearchCallSearchingEvent": ".websearchcallsearchingevent",
    "WebSearchCallSearchingEventType": ".websearchcallsearchingevent",
    "WebSearchCallSearchingEventTypedDict": ".websearchcallsearchingevent",
    "WebSearchEngine": ".websearchengine",
    "WebSearchServerTool": ".websearchservertool",
    "WebSearchServerToolEngine": ".websearchservertool",
    "WebSearchServerToolFilters": ".websearchservertool",
    "WebSearchServerToolFiltersTypedDict": ".websearchservertool",
    "WebSearchServerToolType": ".websearchservertool",
    "WebSearchServerToolTypedDict": ".websearchservertool",
    "WebSearchServerToolOpenRouter": ".websearchservertool_openrouter",
    "WebSearchServerToolOpenRouterParameters": ".websearchservertool_openrouter",
    "WebSearchServerToolOpenRouterParametersTypedDict": ".websearchservertool_openrouter",
    "WebSearchServerToolOpenRouterType": ".websearchservertool_openrouter",
    "WebSearchServerToolOpenRouterTypedDict": ".websearchservertool_openrouter",
    "WebSearchStatus": ".websearchstatus",
    "WebSearchUserLocation": ".websearchuserlocation",
    "WebSearchUserLocationType": ".websearchuserlocation",
    "WebSearchUserLocationTypedDict": ".websearchuserlocation",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
